<?php

namespace Posify\Woocommerce\Authorization;

use Posify\Woocommerce\Policies;

class Gate
{
    protected static $policies = [
        'store' => Policies\StorePolicy::class,
        'register' => Policies\RegisterPolicy::class,
        'register_session' => Policies\RegisterSessionPolicy::class,
        'receipt' => Policies\ReceiptPolicy::class,
        'employee' => Policies\EmployeePolicy::class,
        'register_cash' => Policies\RegisterCashPolicy::class,
        'store_employee' => Policies\StoreEmployeePolicy::class,
        'report' => Policies\ReportPolicy::class,
        'setting' => Policies\SettingPolicy::class,
    ];

    public static function check($policy, $action, ...$args)
    {
        $policy = static::resolvePolicy($policy);

        if (!$policy) {
            return false;
        }

        return $policy->$action(...$args);
    }

    public static function deny($policy, $action, ...$args)
    {
        return static::check($policy, $action, ...$args) == false;
    }

    public static function resolvePolicy($policy)
    {
        $policyClass = static::$policies[$policy] ?? null;

        if (!$policyClass) {
            return false;
        }

        return new $policyClass;
    }
}
