<?php

namespace Posify\Woocommerce\Entities;

use Illuminate\Database\Eloquent\Model;
use Posify\Core\Entities\Receipt as ReceiptEntity;
use Posify\Woocommerce\Utilities\WpTimestamp;

class Receipt extends Model implements ReceiptEntity
{
    use WpTimestamp;

    protected $table = 'posify_receipts';

    protected $guarded = [
        //
    ];

    protected $casts = [
        'show_logo' => 'boolean',
        'show_sku' => 'boolean',
        'show_store_name' => 'boolean',
        'show_vat' => 'boolean',
        'show_address' => 'boolean',
        'show_phone' => 'boolean',
        'show_email' => 'boolean',
        'show_fax' => 'boolean',
        'show_website' => 'boolean',
        'show_facebook' => 'boolean',
        'show_twitter' => 'boolean',
        'show_instagram' => 'boolean',
        'show_youtube' => 'boolean',
        'show_order_date' => 'boolean',
        'show_order_number' => 'boolean',
        'show_order_customer' => 'boolean',
        'show_shipping' => 'boolean',
        'show_order_register' => 'boolean',
        'show_cashier' => 'boolean',
        'show_customer_note' => 'boolean',
    ];

    /**
     * --------------------------
     * Relationships
     * --------------------------
     */

    public function registers()
    {
        return $this->hasMany(Register::class, 'receipt_id');
    }

    /**
     * --------------------------
     * Getters
     * --------------------------
     */

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function getShowLogo(): bool
    {
        return $this->show_logo;
    }

    public function getLogoUrl(): ?string
    {
        return $this->logo_url;
    }

    public function getShowSku(): bool
    {
        return $this->show_sku;
    }

    public function getSkuLabel(): ?string
    {
        return $this->sku_label;
    }

    public function getShowStoreName(): bool
    {
        return $this->show_store_name;
    }

    public function getReceiptFooter(): ?string
    {
        return $this->receipt_footer;
    }

    public function getShowVat(): bool
    {
        return $this->show_vat;
    }

    public function getVatLabel(): ?string
    {
        return $this->vat_label;
    }

    public function getShowAddress(): bool
    {
        return $this->show_address;
    }

    public function getShowPhone(): bool
    {
        return $this->show_phone;
    }

    public function getShowEmail(): bool
    {
        return $this->show_email;
    }

    public function getShowFax(): bool
    {
        return $this->show_fax;
    }

    public function getShowWebsite(): bool
    {
        return $this->show_website;
    }

    public function getShowFacebook(): bool
    {
        return $this->show_facebook;
    }

    public function getShowTwitter(): bool
    {
        return $this->show_twitter;
    }

    public function getShowInstagram(): bool
    {
        return $this->show_instagram;
    }

    public function getShowYoutube(): bool
    {
        return $this->show_youtube;
    }

    public function getShowOrderDate(): bool
    {
        return $this->show_order_date;
    }

    public function getOrderDateLabel(): ?string
    {
        return $this->order_date_label;
    }

    public function getShowOrderNumber(): bool
    {
        return $this->show_order_number;
    }

    public function getOrderNumberLabel(): ?string
    {
        return $this->order_number_label;
    }

    public function getShowOrderCustomer(): bool
    {
        return $this->show_order_customer;
    }

    public function getOrderCustomerLabel(): ?string
    {
        return $this->order_customer_label;
    }

    public function getShowShipping(): bool
    {
        return $this->show_shipping;
    }

    public function getShippingLabel(): ?string
    {
        return $this->shipping_label;
    }

    public function getShowOrderRegister(): bool
    {
        return $this->show_order_register;
    }

    public function getOrderRegisterLabel(): ?string
    {
        return $this->order_register_label;
    }

    public function getShowCashier(): bool
    {
        return $this->show_cashier;
    }

    public function getCashierLabel(): ?string
    {
        return $this->cashier_label;
    }

    public function getCustomerNoteLabel(): ?string
    {
        return $this->customer_note_label;
    }

    public function getShowCustomerNote(): bool
    {
        return $this->show_customer_note;
    }

    /**
     * --------------------------
     * Setters
     * --------------------------
     */

    public function setId($id)
    {
        $this->id = $id;
    }

    public function setName($name)
    {
        return $this->name = $name;
    }

    public function setShowLogo($showLogo)
    {
        return $this->show_logo = $showLogo;
    }

    public function setLogoUrl($logoUrl)
    {
        return $this->logo_url = $logoUrl;
    }

    public function setShowSku($showSku)
    {
        return $this->show_sku = $showSku;
    }

    public function setSkuLabel($skuLabel)
    {
        return $this->sku_label = $skuLabel;
    }

    public function setShowStoreName($showStoreName)
    {
        return $this->show_store_name = $showStoreName;
    }

    public function setReceiptFooter($receiptFooter)
    {
        return $this->receipt_footer = $receiptFooter;
    }

    public function setShowVat($showVat)
    {
        return $this->show_vat = $showVat;
    }

    public function setVatLabel($vatLabel)
    {
        return $this->vat_label = $vatLabel;
    }

    public function setShowAddress($showAddress)
    {
        return $this->show_address = $showAddress;
    }

    public function setShowPhone($showPhone)
    {
        return $this->show_phone = $showPhone;
    }

    public function setShowEmail($showEmail)
    {
        return $this->show_email = $showEmail;
    }

    public function setShowFax($showFax)
    {
        return $this->show_fax = $showFax;
    }

    public function setShowWebsite($showWebsite)
    {
        return $this->show_website = $showWebsite;
    }

    public function setShowFacebook($showFacebook)
    {
        return $this->show_facebook = $showFacebook;
    }

    public function setShowTwitter($showTwitter)
    {
        return $this->show_twitter = $showTwitter;
    }

    public function setShowInstagram($showInstagram)
    {
        return $this->show_instagram = $showInstagram;
    }

    public function setShowYoutube($showYoutube)
    {
        return $this->show_youtube = $showYoutube;
    }

    public function setShowOrderDate($showOrderDate)
    {
        return $this->show_order_date = $showOrderDate;
    }

    public function setOrderDateLabel($orderDateLabel)
    {
        return $this->order_date_label = $orderDateLabel;
    }

    public function setShowOrderNumber($showOrderNumber)
    {
        return $this->show_order_number = $showOrderNumber;
    }

    public function setOrderNumberLabel($orderNumberLabel)
    {
        return $this->order_number_label = $orderNumberLabel;
    }

    public function setShowOrderCustomer($showOrderCustomer)
    {
        return $this->show_order_customer = $showOrderCustomer;
    }

    public function setOrderCustomerLabel($orderCustomerLabel)
    {
        return $this->order_customer_label = $orderCustomerLabel;
    }

    public function setShowShipping($showShipping)
    {
        return $this->show_shipping = $showShipping;
    }

    public function setShippingLabel($shippingLabel)
    {
        return $this->shipping_label = $shippingLabel;
    }

    public function setShowOrderRegister($showOrderRegister)
    {
        return $this->show_order_register = $showOrderRegister;
    }

    public function setOrderRegisterLabel($orderRegisterLabel)
    {
        return $this->order_register_label = $orderRegisterLabel;
    }

    public function setShowCashier($showCashier)
    {
        return $this->show_cashier = $showCashier;
    }

    public function setCashierLabel($cashierLabel)
    {
        return $this->cashier_label = $cashierLabel;
    }

    public function setCustomerNoteLabel($customerNoteLabel)
    {
        return $this->customer_note_label = $customerNoteLabel;
    }

    public function setShowCustomerNote($showCustomerNote)
    {
        return $this->show_customer_note = $showCustomerNote;
    }

    /**
     * --------------------------
     * Assertions
     * --------------------------
     */

    public function isUsedInRegisters(): bool
    {
        return $this->registers()->count() > 0;
    }
}
