<?php

namespace Posify\Woocommerce\Entities;

use Illuminate\Database\Eloquent\Model;
use Posify\Core\Entities\RegisterCash as RegisterCashEntity;
use Posify\Woocommerce\Utilities\WpTimestamp;

class RegisterCash extends Model implements RegisterCashEntity
{
    use WpTimestamp;

    protected $table = 'posify_register_cashes';

    protected $guarded = [
        //
    ];

    /**
     * --------------------------
     * Relationships
     * --------------------------
     */

    public function store()
    {
        return $this->belongsTo(Store::class, 'store_id');
    }

    public function employee()
    {
        return $this->belongsTo(Employee::class, 'employee_id');
    }

    public function register()
    {
        return $this->belongsTo(Register::class, 'register_id');
    }

    public function session()
    {
        return $this->belongsTo(RegisterSession::class, 'session_id');
    }

    public function getStore()
    {
        return $this->store;
    }

    public function getEmployee()
    {
        return $this->employee;
    }

    public function getRegister()
    {
        return $this->register;
    }

    public function getSession()
    {
        return $this->session;
    }

    /**
     * --------------------------
     * Getters
     * --------------------------
     */

    public function getId(): int
    {
        return $this->id;
    }

    public function getStoreId(): ?int
    {
        return $this->store_id;
    }

    public function getEmployeeId(): ?int
    {
        return $this->employee_id;
    }

    public function getRegisterId(): ?int
    {
        return $this->register_id;
    }

    public function getSessionId(): ?int
    {
        return $this->session_id;
    }

    public function getAmount(): ?float
    {
        return $this->amount;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function getCreatedAt()
    {
        return $this->created_at;
    }

    public function getUpdatedAt()
    {
        return $this->updated_at;
    }

    /**
     * --------------------------
     * Setters
     * --------------------------
     */

    public function setId(int $id): void
    {
        $this->id = $id;
    }

    public function setStoreId(?int $storeId): void
    {
        $this->store_id = $storeId;
    }

    public function setEmployeeId(?int $employeeId): void
    {
        $this->employee_id = $employeeId;
    }

    public function setRegisterId(?int $registerId): void
    {
        $this->register_id = $registerId;
    }

    public function setSessionId(?int $sessionId): void
    {
        $this->session_id = $sessionId;
    }

    public function setAmount(?float $amount): void
    {
        $this->amount = $amount;
    }

    public function setDescription(?string $description): void
    {
        $this->description = $description;
    }
}
