<?php

namespace Posify\Woocommerce\Entities;

use Illuminate\Database\Eloquent\Model;
use Posify\Core\Entities\RegisterSession as RegisterSessionEntity;
use Posify\Woocommerce\Utilities\WpTimestamp;

class RegisterSession extends Model implements RegisterSessionEntity
{
    use WpTimestamp;

    protected $table = 'posify_register_sessions';

    protected $guarded = [
        //
    ];

    protected $casts = [
        'open_time' => 'datetime',
        'close_time' => 'datetime',
    ];

    /**
     * --------------------------
     * Relationships
     * --------------------------
     */

    public function register()
    {
        return $this->belongsTo(Register::class, 'register_id');
    }

    public function store()
    {
        return $this->belongsTo(Store::class, 'store_id');
    }

    public function employee()
    {
        return $this->belongsTo(Employee::class, 'employee_id');
    }

    public function orders()
    {
        return $this->hasMany(Order::class, 'register_session_id');
    }

    // Alias for employee
    public function cashier()
    {
        return $this->employee();
    }

    public function employeeActions()
    {
        return $this->hasMany(RegisterSessionEmployee::class, 'session_id');
    }

    public function employees()
    {
        return $this->belongsToMany(Employee::class, 'posify_register_session_employees', 'session_id', 'employee_id')->distinct();
    }

    // Alias for employees
    public function cashiers()
    {
        return $this->employees();
    }

    public function getRegister()
    {
        return $this->register;
    }

    public function getStore()
    {
        return $this->store;
    }

    public function getEmployee()
    {
        return $this->employee;
    }

    public function getCashier()
    {
        return $this->cashier;
    }

    public function getEmployees()
    {
        return $this->employees;
    }

    public function getCashiers()
    {
        return $this->cashiers;
    }

    public function cashes()
    {
        return $this->hasMany(RegisterCash::class, 'session_id');
    }

    /**
     * --------------------------
     * Getters
     * --------------------------
     */

    public function getId(): int
    {
        return $this->id;
    }

    public function getRegisterId(): int
    {
        return $this->register_id;
    }

    public function getStoreId(): int
    {
        return $this->store_id;
    }

    public function getEmployeeId(): int
    {
        return $this->employee_id;
    }

    public function getOpenTime(): string
    {
        return $this->open_time;
    }

    public function getCloseTime(): ?string
    {
        return $this->close_time;
    }

    public function getTotalSales(): float
    {
        return Order::where('register_session_id', $this->id)->sum('order_total');
    }

    public function getNote()
    {
        return $this->note;
    }

    public function getTotalCash(): float
    {
        return $this->cashes()->sum('amount');
    }

    public function totalCash()
    {
        return $this->getTotalCash();
    }

    public function getCashInHandsCount()
    {
        return $this->cashes()->count();
    }

    /**
     * --------------------------
     * Setters
     * --------------------------
     */

    public function setId(int $id): void
    {
        $this->id = $id;
    }

    public function setRegisterId(int $registerId): void
    {
        $this->register_id = $registerId;
    }

    public function setStoreId(int $storeId): void
    {
        $this->store_id = $storeId;
    }

    public function setEmployeeId(int $employeeId): void
    {
        $this->employee_id = $employeeId;
    }

    public function setOpenTime(string $openTime): void
    {
        $this->open_time = $openTime;
    }

    public function setCloseTime(string $closeTime): void
    {
        $this->close_time = $closeTime;
    }

    public function setNote(?string $note): void
    {
        $this->note = $note;
    }

    /**
     * --------------------------
     * Assertions
     * --------------------------
     */

    public function isOpen()
    {
        return $this->open_time && !$this->close_time;
    }
}
