<?php

namespace Posify\Woocommerce\Entities;

use Illuminate\Database\Eloquent\Model;
use Posify\Core\Entities\Stock as StockEntity;
use Posify\Woocommerce\Utilities\WpTimestamp;

class Stock extends Model implements StockEntity
{
    use WpTimestamp;

    protected $table = 'posify_stocks';

    protected $guarded = [
        //
    ];

    /**
     * --------------------------
     * Relationships
     * --------------------------
     */

    public function store()
    {
        return $this->belongsTo(StoreModel::class, 'store_id');
    }

    public function getStore()
    {
        return $this->store;
    }

    /**
     * --------------------------
     * Getters
     * --------------------------
     */

    public function getId()
    {
        return $this->id;
    }

    public function getProductId()
    {
        return $this->product_id;
    }

    public function getStoreId()
    {
        return $this->store_id;
    }

    public function getStockQuantity()
    {
        return $this->stock_quantity;
    }

    public function getStockStatus()
    {
        if ($this->stock_quantity <= 0) {
            return 'outofstock';
        }

        return 'instock';
    }

    /**
     * --------------------------
     * Setters
     * --------------------------
     */

    public function setStoreId($storeId)
    {
        $this->store_id = $storeId;
    }

    public function setStockQuantity($stockQuantity)
    {
        $this->stock_quantity = $stockQuantity;
    }

    public function setStockStatus($stockStatus)
    {
        $this->stock_status = $stockStatus;
    }

    public function setProductId($productId)
    {
        $this->product_id = $productId;
    }

    public function setVariantId($variantId)
    {
        $this->variant_id = $variantId;
    }

    /**
     * --------------------------
     * Actions
     * --------------------------
     */

    public function decrementQuantity($decrementNumber)
    {
        return $this->decrement('stock_quantity', $decrementNumber);
    }

    public function incrementQuantity($incrementNumber)
    {
        return $this->increment('stock_quantity', $incrementNumber);
    }
}
