<?php

namespace Posify\Woocommerce\Http\Api\Controllers;

use Posify\CustomerLicense\LicenseManager;
use Posify\Woocommerce\Http\Common\Controllers\BaseController;
use WP_REST_Request;

class CustomerLicenseController extends BaseController
{
    public function status()
    {
        if (posify_is_pro_version() == false) {
            return $this->json([
                'status' => true
            ]);
        }

        $licenseManager = LicenseManager::getInstance();
        $license = $licenseManager->getLicense();

        if ($license) {
            return $this->json([
                'status' => 'inactive',
            ]);
        }

        return $this->json([
            'license' => $license->toArray(),
            'license_string' => $licenseManager->getLicenseAsString(),
        ]);
    }

    public function active(WP_REST_Request $request)
    {
        $licenseKey = $request->get_param('key');

        $licenseManager = LicenseManager::getInstance();

        [$status, $message] = $licenseManager->verify($licenseKey);

        if ($status == false) {
            return $this->json([
                'message' => $message,
            ], 400);
        }

        $licenseManager->setLicenseKey($licenseKey);
        $licenseManager->saveLicenseKey();
        $license = $licenseManager->getLicense();

        return $this->json([
            'license' => $license->toArray(),
            'license_string' => $licenseManager->getLicenseAsString(),
        ]);
    }

    public function remove()
    {
        $licenseManager = LicenseManager::getInstance();
        $licenseManager->removeLicense();

        return $this->json([]);
    }
}
