<?php

namespace Posify\Woocommerce\Http\Api\Controllers;

use Posify\Core\DataTransferObjects\EmployeeQueryArgs;
use Posify\Core\Loader;
use Posify\Core\Repositories\EmployeeRepository;
use Posify\Woocommerce\Authorization\Gate;
use Posify\Woocommerce\Http\Common\Controllers\BaseController;
use WP_REST_Request;

class EmployeeController extends BaseController
{
    protected $employeeRepo;

    public function __construct()
    {
        $this->employeeRepo = Loader::load(EmployeeRepository::class);
    }

    public function index(WP_REST_Request $wpRequest)
    {
        if (Gate::deny('employee', 'read')) {
            return $this->forbidden();
        }

        $args = EmployeeQueryArgs::make($wpRequest->get_params());

        $args->setPage(
            $wpRequest->get_param('page') ?? 1
        );

        $args->setPerPage(
            $wpRequest->get_param('per_page') ?? 15
        );

        $pagination = $this->employeeRepo->paginate($args)
            ->through(function ($employee) {
                return [
                    'id' => $employee->getId(),
                    'email' => $employee->getEmail(),
                    'username' => $employee->getUsername(),
                    'full_name' => $employee->getFullName(),
                    'avatar_url' => $employee->getAvatarUrl(),
                    'role' => $employee->getRole(),
                ];
            })
            ->toArray();

        $response = $this->json($pagination['data']);
        $response->header('X-WP-Total', $pagination['total']);
        $response->header('X-WP-TotalPages', $pagination['last_page']);

        return $response;
    }
}
