<?php

namespace Posify\Woocommerce\Http\Api\Controllers;

use Posify\Core\Loader;

use Posify\Core\Repositories\RegisterSessionRepository;
use Posify\Woocommerce\Authorization\Gate;
use Posify\Woocommerce\Http\Common\Controllers\BaseController;
use WP_REST_Request;

class PosController extends BaseController
{
    protected $registerSessionRepo;

    protected $session;

    public function __construct()
    {
        $this->registerSessionRepo = Loader::load(RegisterSessionRepository::class);
    }

    /**
     * Get all needed data for POS after login
     *
     * This endpoint may be same current register session endpoint
     */
    public function __invoke(WP_REST_Request $wpRequest)
    {
        $this->session = $this->registerSessionRepo->find($wpRequest->get_param('session_id'));

        if (!$this->session) {
            return $this->json(null);
        }

        if (Gate::deny('register_session', 'read', $this->session)) {
            return $this->forbidden();
        }

        return $this->json([
            'store' => $this->getStore(),
            'register' => $this->getRegister(),
            'register_session' => $this->getReigsterSession(),
            'receipt' => $this->getReceipt(),
        ], 200);
    }

    private function getStore()
    {
        $store = $this->session->getStore();

        return [
            'id' => $store->getId(),
            'name' => $store->getName(),
            'vat_number' => $store->getVatNumber(),

            // Address properties
            'address' => $store->getAddress(),
            'formatted_address' => $store->getFormattedAddress(),
            'city' => $store->getCity(),
            'country_state' => $store->getCountryState(),
            'postcode' => $store->getPostcode(),

            // Contact properties
            'phone' => $store->getPhone(),
            'email' => $store->getEmail(),
            'website' => $store->getWebsite(),
            'fax' => $store->getFax(),

            // Social properties
            'twitter' => $store->getTwitter(),
            'facebook' => $store->getFacebook(),
            'instagram' => $store->getInstagram(),
            'youtube' => $store->getYoutube(),
            'enabled' => $store->getEnabled(),
        ];
    }

    private function getRegister()
    {
        $register = $this->session->getRegister();

        return [
            'id' => $register->getId(),
            'name' => $register->getName(),
            'payment_gateways' => $register->getPaymentGateways(),
            'default_payment_gateway' => $register->getDefaultPaymentGateway(),
            'shipping_methods' => $register->getShippingMethods(),
            'default_shipping_method' => $register->getDefaultShippingMethod(),
            'tax_classes' => $register->getTaxClasses(),
            'default_tax_class' => $register->getDefaultTaxClass(),
            'tax_status' => $register->getTaxStatus(),
            'default_tax_status' => $register->getDefaultTaxStatus(),
            'closing_report_enabled' => $register->getClosingReportEnabled(),
            'closing_report_note_enabled' => $register->getClosingReportNoteEnabled(),
            'catalog_include_type' => $register->getCatalogIncludeType(),
            'catalog_include_prroducts' => $register->getCatalogIncludeProducts(),
            'catalog_include_categories' => $register->getCatalogIncludeCategories(),
            'catalog_show_in_pos_type' => $register->getCatalogShowInPosType(),
            'numeric_controller_discount_presets' => $register->getNumericControllerDiscountPresets(),
            'fee_and_discount_presets' => $register->getFeeAndDiscountPresets(),
            'audio_enabled' => $register->getAudioEnabled(),
            'scan_enabled' => $register->getScanEnabled(),
            'auto_print_receipt_enabled' => $register->getAutoPrintReceiptEnabled(),
            'guest_checkout_enabled' => $register->getGuestCheckoutEnabled(),
            'create_product_enabled' => $register->getCreateProductEnabled(),
            'shipping_enabled' => $register->getShippingEnabled(),
            'enabled' => $register->getEnabled(),
            'show_stock_quantity' => $register->getShowStockQuantity(),
        ];
    }

    private function getReceipt()
    {
        $register = $this->session->getRegister();

        $receipt = $register->getReceipt();

        return [
            'id' => $receipt->getId(),
            'name' => $receipt->getName(),
            'show_logo' => $receipt->getShowLogo(),
            'logo_url' => $receipt->getLogoUrl(),
            'show_sku' => $receipt->getShowSku(),
            'sku_label' => $receipt->getSkuLabel(),
            'show_store_name' => $receipt->getShowStoreName(),
            'receipt_footer' => $receipt->getReceiptFooter(),
            'show_vat' => $receipt->getShowVat(),
            'vat_label' => $receipt->getVatLabel(),
            'show_address' => $receipt->getShowAddress(),
            'show_phone' => $receipt->getShowPhone(),
            'show_email' => $receipt->getShowEmail(),
            'show_fax' => $receipt->getShowFax(),
            'show_website' => $receipt->getShowWebsite(),
            'show_facebook' => $receipt->getShowFacebook(),
            'show_twitter' => $receipt->getShowTwitter(),
            'show_instagram' => $receipt->getShowInstagram(),
            'show_youtube' => $receipt->getShowYoutube(),
            'show_order_date' => $receipt->getShowOrderDate(),
            'order_date_label' => $receipt->getOrderDateLabel(),
            'show_order_number' => $receipt->getShowOrderNumber(),
            'order_number_label' => $receipt->getOrderNumberLabel(),
            'show_order_customer' => $receipt->getShowOrderCustomer(),
            'order_customer_label' => $receipt->getOrderCustomerLabel(),
            'show_shipping' => $receipt->getShowShipping(),
            'shipping_label' => $receipt->getShippingLabel(),
            'show_order_register' => $receipt->getShowOrderRegister(),
            'order_register_label' => $receipt->getOrderRegisterLabel(),
            'show_cashier' => $receipt->getShowCashier(),
            'cashier_label' => $receipt->getCashierLabel(),
            'show_customer_note' => $receipt->getShowCustomerNote(),
            'customer_note_label' => $receipt->getCustomerNoteLabel(),
        ];
    }

    private function getReigsterSession()
    {
        return [
            'id' => $this->session->getId(),
            'cash_in_hands_count' => $this->session->getCashInHandsCount(),
            'cash_in_hand_histories' => [],
        ];
    }
}
