<?php

namespace Posify\Woocommerce\Http\Api\Controllers\ReportController;

use Posify\Core\Loader;
use Posify\Core\Repositories\EmployeeRepository;
use Posify\Core\Repositories\RegisterRepository;
use Posify\Woocommerce\Authorization\Gate;
use Posify\Woocommerce\Http\Api\Response\DetailRegisterSessionResponse;
use Posify\Woocommerce\Http\Common\Controllers\BaseController;
use Posify\Woocommerce\Reports\RegisterSessionReport;
use WP_REST_Request;

class CurrentRegisterSessionReportAction extends BaseController
{
    public function __invoke(WP_REST_Request $wpRequest)
    {
        if (Gate::deny('report', 'read')) {
            return $this->forbidden();
        }

        $registerRepo = Loader::load(RegisterRepository::class);

        $register = $registerRepo->find($wpRequest->get_param('register_id'));

        if (!$register) {
            return $this->notFound(esc_html__('Register not found', 'posify-for-woocommerce'));
        }

        $currentSession = $register->getCurrentSession();

        if (!$currentSession) {
            return $this->notFound(esc_html__('Current session not found', 'posify-for-woocommerce'));
        }

        if (Gate::deny('register_session', 'read', $currentSession)) {
            return $this->forbidden();
        }

        $employeeRepo = Loader::load(EmployeeRepository::class);
        $employee = null;

        $reportQueryArgs = [
            'session' => $currentSession,
        ];

        if ($employeeId = $wpRequest->get_param('employee_id')) {
            $employee = $employeeRepo->find($employeeId);
            $reportQueryArgs['employee'] = $employee;
        }

        $report = RegisterSessionReport::make($reportQueryArgs);

        $context = $wpRequest->get_param('context');

        return $this->json(
            DetailRegisterSessionResponse::make($currentSession, $report, $context)->toArray()
        );
    }
}
