<?php

namespace Posify\Woocommerce\Http\Api\Response;

use Posify\Core\Entities\RegisterSession;
use Posify\Woocommerce\Reports\RegisterSessionReport;

class DetailRegisterSessionResponse
{
    public RegisterSession $session;
    public RegisterSessionReport $report;

    /**
     * Context of the response
     *
     * Supported values: quick_report, view
     *
     * @var string
     */
    public ?string $context;

    public function __construct(
        RegisterSession $session,
        RegisterSessionReport $report,
        ?string $context = 'view'
    ) {
        $this->session = $session;
        $this->report = $report;
        $this->context = $context;
    }

    public static function make(RegisterSession $session, RegisterSessionReport $report, ?string $context = 'view'): self
    {
        return new self(
            $session,
            $report,
            $context
        );
    }

    public function toArray()
    {
        $register = $this->session->getRegister();
        $store = $this->session->getStore();

        $quickReport = [
            'id' => $this->session->getId(),
            'orders_count' => $this->report->getOrdersCount(),
            'num_items_sold' => $this->report->getNumItemsSold(),
            'total_sales' => $this->report->getTotalSales(),
            'total_discounts' => $this->report->getTotalDiscounts(),
            'cash' => $this->report->getCash(),
            'cash_total' => $this->report->getCashTotal(),
            'net_total' => $this->report->getNetTotal(),
            'cash_in_hand' => $this->report->getCashInHand(),
            'cashiers' => $this->report->getCashiers(),
            'open_time' => $this->session->getOpenTime(),
            'close_time' => $this->session->getCloseTime(),
        ];

        if ($this->context === 'quick_report') {
            return $quickReport;
        }

        return array_merge($quickReport, [
            'register_id' => $this->session->getRegisterId(),
            'employee_id' => $this->session->getEmployeeId(),

            'register' => [
                'id' => $this->session->getRegisterId(),
                'name' => $register ? $register->getName() : null,
            ],

            'store' => [
                'id' => $this->session->getStoreId(),
                'name' => $store ? $store->getName() : null,
            ],

            'note' => $this->session->getNote(),
            'payment_gateways' => $this->report->getPaymentGatewaysWithTotalSale(),
            'cashier_actions' => $this->report->getCashierActions(),
            'cash_changes' => $this->report->getCashChanges(),
        ]);
    }
}
