<?php

namespace Posify\Woocommerce\Http\Common\Controllers;

use WP_Error;
use WP_REST_Response;

class BaseController
{
    protected $request;

    public function __construct()
    {
        //
    }

    protected function view($path, $data = [])
    {
        posify_view($path, $data);
    }

    protected function json($response, $statusCode = 200)
    {
        return new WP_REST_Response($response, $statusCode);
    }

    protected function jsonError($code = '', $message = '', $data = '')
    {
        if (is_wp_error($code)) {
            return $code;
        }

        return new WP_Error($code, $message, $data);
    }

    protected function user()
    {
        return wp_get_current_user();
    }

    protected function invalidParams($message = 'Invalid params', $code = 'invalid_params')
    {
        return $this->jsonError(
            $code,
            $message,
            ['status' => 422]
        );
    }

    protected function forbidden($message = 'Forbidden')
    {
        return $this->jsonError(
            'forbidden',
            $message,
            ['status' => 403]
        );
    }

    protected function notFound($message = 'Not found')
    {
        return $this->jsonError(
            'not_found',
            $message,
            ['status' => 404]
        );
    }
}
