<?php

namespace Posify\Woocommerce\Installer;

use Posify\Core\Loader;
use Posify\Core\Repositories\ReceiptRepository;
use Posify\Core\Repositories\RegisterRepository;
use Posify\Core\Repositories\StoreRepository;

class DefaultData
{
    protected $defaultReceipt;
    protected $defaultStore;
    protected $defaultRegister;

    protected $storeRepository;
    protected $registerRepository;
    protected $receiptRepository;

    public function __construct()
    {
        $this->storeRepository = Loader::load(StoreRepository::class);
        $this->registerRepository = Loader::load(RegisterRepository::class);
        $this->receiptRepository = Loader::load(ReceiptRepository::class);
    }

    public static function run()
    {
        $option = get_option('posify_has_default_data', null);

        if ($option) {
            return;
        }

        $runner = new static();
        $runner->createDefaultReceipt();
        $runner->createDefaultSettings();
        $runner->createDefaultStore();
        $runner->createDefaultRegister();

        update_option('posify_has_default_data', true);
    }

    public function createDefaultReceipt()
    {
        $this->defaultReceipt = $this->receiptRepository->findOrCreateDefaultReceipt();
    }

    public function createDefaultStore()
    {
        $this->defaultStore = $this->storeRepository->findOrCreateDefaultStore();
    }

    public function createDefaultRegister()
    {
        $this->defaultRegister = $this->registerRepository->findOrCreateDefaultRegister($this->defaultStore, $this->defaultReceipt);
    }

    public function createDefaultSettings()
    {
        posify_update_setting([
            'login_background_color' => '',
            'primary_color' => '#1a74e4',
            'secondary_color' => '#1a74e4',
            'info_color' => '#0093ed',
            'positive_color' => '#2ba848',
            'negative_color' => '#a83326',
            'multistock_condition' => 'allowed',
        ]);
    }
}
