<?php

namespace Posify\Woocommerce\Payment;

use WC_Payment_Gateway;

class PosifyCashPaymentGateway extends WC_Payment_Gateway
{
    public const ID = 'posify_cash_payment';

    public function __construct()
    {
        $this->id = static::ID;
        $this->icon = '';
        $this->method_title = esc_html__('Cash Payment', 'posify-for-woocommerce');
        $this->method_description = esc_html__('Pay with cash upon delivery.', 'posify-for-woocommerce');
        $this->has_fields = false;

        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');

        add_action('woocommerce_update_options_payment_gateways_' . $this->id, [$this, 'process_admin_options']);
    }

    public function init_form_fields()
    {
        $this->form_fields = [
            'enabled' => [
                'title' => esc_html__('Enable/Disable', 'posify-for-woocommerce'),
                'type' => 'checkbox',
                'label' => esc_html__('Enable Cash Payment', 'posify-for-woocommerce'),
                'default' => 'yes',
            ],
            'title' => [
                'title' => esc_html__('Title', 'posify-for-woocommerce'),
                'type' => 'text',
                'description' => esc_html__('This controls the title which the user sees during checkout.', 'posify-for-woocommerce'),
                'default' => esc_html__('Cash Payment', 'posify-for-woocommerce'),
                'desc_tip' => true,
            ],
            'description' => [
                'title' => esc_html__('Description', 'posify-for-woocommerce'),
                'type' => 'textarea',
                'description' => esc_html__('This controls the description which the user sees during checkout.', 'posify-for-woocommerce'),
                'default' => esc_html__('Pay with cash upon delivery.', 'posify-for-woocommerce'),
            ],
        ];
    }

    public function process_payment($order_id)
    {
        $order = wc_get_order($order_id);

        $order->update_status('processing', esc_html__('Awaiting cash payment', 'posify-for-woocommerce'));

        return [
            'result' => 'success',
            'redirect' => $this->get_return_url($order),
        ];
    }
}
