<?php

namespace Posify\Woocommerce\Policies;

use Posify\Core\Entities\RegisterCash;
use Posify\Core\Entities\RegisterSession;
use Posify\Woocommerce\Authorization\Auth;
use Posify\Woocommerce\Enums\EmployeeRoles;

class RegisterCashPolicy extends Policy
{
    public function read(?RegisterCash $cash = null)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'read',
            $cash,
            'posify_register_cash'
        );

        if ($result && $cash && Auth::can('posify_only_their_data')) {
            $store = $cash->getStore();

            $result = (
                // The employee is the one who created the cash
                $cash->getEmployee()->getId() === Auth::user()->getId()

                // or the employee is a manager of the store
                || ($store && $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER))
            );
        }

        return $result;
    }

    public function create(RegisterSession $registerSession)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'create',
            null,
            'posify_register_cash'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $registerSession->getStore();

            $result = (
                // The employee is the one who created the session
                $registerSession->getEmployeeId() === Auth::user()->getId()

                // or the employee is a manager of the store
                || ($store && $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER))
            );
        }

        return $result;
    }
}
