<?php

namespace Posify\Woocommerce\Policies;

use Posify\Core\Entities\Register;
use Posify\Core\Entities\Store;
use Posify\Woocommerce\Authorization\Auth;
use Posify\Woocommerce\Enums\EmployeeRoles;

class RegisterPolicy extends Policy
{
    public function read(?Register $register)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'read',
            $register,
            'posify_register'
        );

        if ($result && $register && Auth::can('posify_only_their_data')) {
            $store = $register->getStore();
            $result = $store->hasEmployee(Auth::user());
        }

        return $result;
    }

    public function create(Store $forStore)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'create',
            null,
            'posify_register'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $result = $forStore->hasEmployee(Auth::user(), EmployeeRoles::MANAGER);
        }

        return $result;
    }

    public function update(Register $register)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'edit',
            $register,
            'posify_register'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $register->getStore();
            $result = $store && $store->hasEmployee(Auth::user());
        }

        return $result;
    }

    public function delete(Register $register)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'delete',
            $register,
            'posify_register'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $register->getStore();
            $result = $store && $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER);
        }

        return $result;
    }
}
