<?php

namespace Posify\Woocommerce\Policies;

use Posify\Core\Entities\Register;
use Posify\Core\Entities\RegisterSession;
use Posify\Woocommerce\Authorization\Auth;
use Posify\Woocommerce\Enums\EmployeeRoles;
use Posify\Woocommerce\Policies\Policy;

class RegisterSessionPolicy extends Policy
{
    public function read(?RegisterSession $session = null): bool
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'read',
            $session,
            'posify_register_session'
        );

        if ($result && $session && Auth::can('posify_only_their_data')) {
            $store = $session->getRegister()->getStore();

            $result = (
                // Current session is keeping track of the current user
                $session->getEmployeeId() == Auth::user()->getId()

                // or the current user is a manager of the store
                || ($store && $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER))
            );
        }

        return $result;
    }

    public function create(Register $register)
    {
        $result = apply_filters(
            'posify_check_permissions',
            false,
            'create',
            null,
            'posify_register_session'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $register->getStore();
            $result = $store && $store->hasEmployee(Auth::user());
        }

        return $result;
    }

    public function update(RegisterSession $session)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'edit',
            $session,
            'posify_register_session'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $session->getRegister()->getStore();

            $result = (
                // Current session is keeping track of the current user
                $session->getEmployeeId() == Auth::user()->getId()

                // or the current user is a manager of the store
                || ($store && $store->hasEmployee(Auth::user()))
            );
        }

        return $result;
    }

    public function delete(RegisterSession $session)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'delete',
            $session,
            'posify_register_session'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $store = $session->getRegister()->getStore();

            $result = (
                // Current session is keeping track of the current user
                $session->getEmployeeId() == Auth::user()->getId()

                // or the current user is a manager of the store
                || ($store && $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER))
            );
        }

        return $result;
    }
}

