<?php

namespace Posify\Woocommerce\Policies;

use Posify\Core\Entities\Store;
use Posify\Woocommerce\Authorization\Auth;
use Posify\Woocommerce\Enums\EmployeeRoles;

class StoreEmployeePolicy extends Policy
{
    public function create(Store $store)
    {
        $result = apply_filters(
            'posify_check_permissions',
            false,
            'create',
            null,
            'posify_employee_store'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $result = $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER);
        }

        return $result;
    }

    public function update(Store $store)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'edit',
            $store,
            'posify_employee_store'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $result = $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER);
        }

        return $result;
    }

    public function delete(Store $store)
    {
        $result = apply_filters(
            'posify_check_permissions',
            null,
            'delete',
            $store,
            'posify_employee_store'
        );

        if ($result && Auth::can('posify_only_their_data')) {
            $result = $store->hasEmployee(Auth::user(), EmployeeRoles::MANAGER);
        }

        return $result;
    }
}

