<?php

namespace Posify\Woocommerce\Reports;

use Posify\Core\DataTransferObjects\OverviewReportQuery;
use Posify\Core\Entities\Employee;
use Posify\Core\Reports\AbstractOverviewReport;
use Posify\Woocommerce\DB;
use Posify\Woocommerce\Entities\Order;

class OverviewReport extends AbstractOverviewReport
{
    protected $totalSales = 0;
    protected $totalItems = 0;
    protected $totalDiscounts = 0;
    protected $totalOrders = 0;
    protected $totalCustomers = 0;

    public OverviewReportQuery $query;
    public ?Employee $owner = null;

    public function __construct(
        OverviewReportQuery $query,
        ?Employee $owner = null
    ) {
        $this->query = $query;
        $this->owner = $owner;
    }

    public static function make(OverviewReportQuery $query, ?Employee $owner = null)
    {
        return new static($query, $owner);
    }

    public function calculate()
    {
        $query = Order::query()
            ->selectRaw('sum(order_total) as total_sales')
            ->selectRaw('sum(total_items) as total_items')
            ->selectRaw('sum(cart_discount) as total_discounts')
            ->selectRaw('count('. DB::getTablePrefix() . 'posify_orders.id) as total_orders')
            ->selectRaw('count(distinct customer_id) as total_customers')
            ->when($this->owner, function ($query) {
                $query
                    ->join('posify_store_has_employees', 'posify_store_has_employees.store_id', '=', 'posify_orders.store_id')
                    ->where('posify_store_has_employees.employee_id', $this->owner->getId());
            })
            ->when($this->query->store_id, function ($query) {
                $query->where('store_id', $this->query->store_id);
            })
            ->when($this->query->register_id, function ($query) {
                $query->where('register_id', $this->query->register_id);
            })
            ->when($this->query->start_time, function ($query) {
                $query->where('posify_orders.created_at', '>=', $this->query->start_time);
            })
            ->when($this->query->end_time, function ($query) {
                $query->where('posify_orders.created_at', '<=', $this->query->end_time);
            });

        $results = $query->first();

        $this->totalSales = (float) $results->total_sales;
        $this->totalItems = (int) $results->total_items;
        $this->totalDiscounts = (float) $results->total_discounts;
        $this->totalOrders = (int) $results->total_orders;
        $this->totalCustomers = (int) $results->total_customers;
    }

    public function getTotalSales(): float
    {
        return $this->totalSales;
    }

    public function getTotalItems(): int
    {
        return $this->totalItems;
    }

    public function getTotalDiscounts(): float
    {
        return $this->totalDiscounts;
    }

    public function getTotalOrders(): int
    {
        return $this->totalOrders;
    }

    public function getTotalCustomers(): int
    {
        return $this->totalCustomers;
    }
}
