<?php

namespace Posify\Woocommerce\Repositories;

use Posify\Core\DataTransferObjects\EmployeeQueryArgs;
use Posify\Core\Repositories\EmployeeRepository as CoreEmployeeRepository;
use Posify\Core\ValueObjects\Undefined;
use Posify\Woocommerce\Entities\Employee;

class EmployeeRepository extends EloquentRepository implements CoreEmployeeRepository
{
    public function find(int $id): ?Employee
    {
        return Employee::find($id);
    }

    public function query(EmployeeQueryArgs $args)
    {
        return Employee::query()
            ->when($args->getWith(), function ($query) use ($args) {
                $query->with($args->getWith());
            })
            ->when($args->getSort(), function ($query) use ($args) {
                $query->orderBy($args->getSort(), $args->getOrder());
            })
            ->when($args->id, function ($query) use ($args) {
                $query->where('id', $args->id);
            })
            ->when($args->search, function ($query) use ($args) {
                $query->where(function ($query) use ($args) {
                    $query->where('user_email', 'like', "{$args->search}%")
                        ->orWhere('user_login', 'like', "{$args->search}%")
                        ->orWhere('display_name', 'like', "{$args->search}%");
                });
            })
            ->when($args->store_id, function ($query) use ($args) {
                $query->whereHas('stores', function ($query) use ($args) {
                    $query->where('posify_stores.id', $args->store_id);
                });
            })
            ->when(Undefined::isNot($args->enabled_in_store), function ($query) use ($args) {
                $query->whereHas('dataInStore', function ($query) use ($args) {
                    $query->where('enabled', $args->enabled_in_store);
                });
            });
    }

    public function paginate(EmployeeQueryArgs $args)
    {
        return $this
            ->query($args)
            ->paginate($args->getPerpage(), $args->getSelect(), $args->getPageParam(), $args->getPage());
    }

    public function dumpRawSql(EmployeeQueryArgs $args)
    {
        return $this->query($args)->dumpRawSql();
    }
}
