<?php

namespace Posify\Woocommerce\Repositories;

use Posify\Core\DataTransferObjects\ReceiptQueryArgs;
use Posify\Core\Repositories\ReceiptRepository as CoreReceiptRepository;
use Posify\Woocommerce\Entities\Receipt;

class ReceiptRepository extends EloquentRepository implements CoreReceiptRepository
{
    public function query(ReceiptQueryArgs $args)
    {
        return Receipt::query()
            ->when($args->getWith(), function ($query) use ($args) {
                $query->with($args->getWith());
            })
            ->when($args->getSort(), function ($query) use ($args) {
                $query->orderBy($args->getSort(), $args->getOrder());
            })
            ->when($args->id, function ($query) use ($args) {
                $query->where('id', $args->id);
            })
            ->when($args->keyword, function ($query) use ($args) {
                $query->where('name', 'like', $args->keyword . '%');
            });
    }

    public function paginate(ReceiptQueryArgs $args)
    {
        return $this
            ->query($args)
            ->paginate($args->getPerpage(), $args->getSelect(), $args->getPageParam(), $args->getPage());
    }

    public function find(int $id): ?Receipt
    {
        return Receipt::find($id);
    }

    public function exists(int $id): bool
    {
        return Receipt::where('id', $id)->exists();
    }


    public function findOrCreateDefaultReceipt(): ?Receipt
    {
        $receipt = Receipt::query()->orderBy('id', 'asc')->first();

        if (!$receipt) {
            $receipt = posify_create_receipt([
                'name' => esc_html__('Default Receipt', 'posify-for-woocommerce'),
                'show_logo' => false,
                'logo_url' => null,
                'show_sku' => true,
                'sku_label' => esc_html__('SKU', 'posify-for-woocommerce'),
                'show_store_name' => true,
                'receipt_footer' => esc_html__('Thank you for shopping with us!', 'posify-for-woocommerce'),
                'show_vat' => true,
                'vat_label' => esc_html__('VAT', 'posify-for-woocommerce'),
                'show_address' => false,
                'show_phone' => false,
                'show_email' => false,
                'show_fax' => false,
                'show_website' => false,
                'show_facebook' => false,
                'show_twitter' => false,
                'show_instagram' => false,
                'show_youtube' => false,
                'show_order_date' => true,
                'order_date_label' => esc_html__('Order Date', 'posify-for-woocommerce'),
                'show_order_number' => true,
                'order_number_label' => esc_html__('Order Number', 'posify-for-woocommerce'),
                'show_order_customer' => true,
                'order_customer_label' => esc_html__('Customer', 'posify-for-woocommerce'),
                'show_shipping' => true,
                'shipping_label' => esc_html__('Shipping', 'posify-for-woocommerce'),
                'show_order_register' => true,
                'order_register_label' => esc_html__('Register', 'posify-for-woocommerce'),
                'show_cashier' => true,
                'cashier_label' => esc_html__('Cashier', 'posify-for-woocommerce'),
                'show_customer_note' => true,
                'customer_note_label' => esc_html__('Customer Note', 'posify-for-woocommerce'),
            ]);
        }

        return $receipt;
    }
}
