<?php

namespace Posify\Woocommerce\Repositories;

use Posify\Core\DataTransferObjects\RegisterSessionQueryArgs;
use Posify\Core\Repositories\RegisterSessionRepository as CoreRegisterSessionRepository;
use Posify\Woocommerce\Entities\RegisterSession;

class RegisterSessionRepository extends EloquentRepository implements CoreRegisterSessionRepository
{
    public function query(RegisterSessionQueryArgs $args)
    {
        return RegisterSession::query()
            ->when($args->getWith(), function ($query) use ($args) {
                $query->with($args->getWith());
            })
            ->when($args->getSort(), function ($query) use ($args) {
                $query->orderBy($args->getSort(), $args->getOrder());
            })
            ->when($args->id, function ($query) use ($args) {
                $query->where('id', $args->id);
            })
            ->when($args->store_id, function ($query) use ($args) {
                $query->where('store_id', $args->store_id);
            })
            ->when($args->register_id, function ($query) use ($args) {
                $query->where('register_id', $args->register_id);
            })
            ->when($args->open_date, function ($query) use ($args) {
                $openTime = posify_date_format($args->open_date_format ?? 'Y-m-d', $args->open_date);

                if ($openTime) {
                    $query->whereDate('open_time', $openTime->startOfDay());
                }
            })
            ->when($args->close_date, function ($query) use ($args) {
                $closeTime = posify_date_format($args->close_date_format ?? 'Y-m-d', $args->close_date);

                if ($closeTime) {
                    $query->whereDate('close_time', $closeTime->startOfDay());
                }
            })
            ->when($args->employee_id, function ($query) use ($args) {
                $query->where('employee_id', $args->employee_id);
            })
            ->when($args->store_has_employee_id, function ($query) use ($args) {
                $query->whereHas('store', function ($query) use ($args) {
                    $query->whereHas('employees', function ($query) use ($args) {
                        $query->where('users.ID', $args->store_has_employee_id);
                    });
                });
            })
            ->when($args->time_status, function ($query) use ($args) {
                if ($args->time_status === 'open') {
                    $query->whereNull('close_time');
                } elseif ($args->time_status === 'closed') {
                    $query->whereNotNull('close_time');
                }
            });
    }

    public function paginate(RegisterSessionQueryArgs $args)
    {
        return $this
            ->query($args)
            ->paginate($args->getPerpage(), $args->getSelect(), $args->getPageParam(), $args->getPage());
    }

    public function find(int $id): ?RegisterSession
    {
        return RegisterSession::find($id);
    }

    public function exists(int $id): bool
    {
        return RegisterSession::where('id', $id)->exists();
    }
}
