<?php

namespace Posify\Woocommerce\Repositories;

use Posify\Core\DataTransferObjects\StockQueryArgs;
use Posify\Core\Repositories\StockRepository as CoreStockRepository;
use Posify\Woocommerce\Entities\Stock;

class StockRepository extends EloquentRepository implements CoreStockRepository
{
    public function all(StockQueryArgs $args)
    {
        return $this
            ->query($args)
            ->get();
    }

    public function query(StockQueryArgs $args)
    {
        return Stock::query()
            ->when($args->getSelect(), function ($query) use ($args) {
                $query->select($args->getSelect());
            })
            ->when($args->getWith(), function ($query) use ($args) {
                $query->with($args->getWith());
            })
            ->when($args->getSort(), function ($query) use ($args) {
                $query->orderBy($args->getSort(), $args->getOrder());
            })
            ->when($args->id, function ($query) use ($args) {
                $query->where('id', $args->id);
            })
            ->when($args->store_id, function ($query) use ($args) {
                $query->where('store_id', $args->store_id);
            })
            ->when($args->store_ids, function ($query) use ($args) {
                $query->whereIn('store_id', $args->store_ids);
            })
            ->when($args->store_id_not_in, function ($query) use ($args) {
                $query->whereNotIn('store_id', $args->store_id_not_in);
            })
            ->when($args->product_id, function ($query) use ($args) {
                $query->where('product_id', $args->product_id);
            })
            ->when($args->variant_id, function ($query) use ($args) {
                if ($args->variant_id === 'is_null') {
                    $query->whereNull('variant_id');
                    return;
                }

                $query->where('variant_id', $args->variant_id);
            });
    }

    public function paginate(StockQueryArgs $args)
    {
        return $this
            ->query($args)
            ->paginate($args->getPerpage(), $args->getSelect(), $args->getPageParam(), $args->getPage());
    }

    public function find(int $id): ?Stock
    {
        return Stock::find($id);
    }

    public function findWhere(StockQueryArgs $args): ?Stock
    {
        return $this->query($args)->first();
    }

    public function exists(int $id): bool
    {
        return Stock::where('id', $id)->exists();
    }

    public function delete(StockQueryArgs $args)
    {
        return $this->query($args)->delete();
    }
}
