<?php

namespace Posify\Woocommerce\Repositories;

use Posify\Core\DataTransferObjects\StoreQueryArgs;
use Posify\Core\Repositories\StoreRepository as CoreStoreRepository;
use Posify\Core\ValueObjects\Undefined;
use Posify\Woocommerce\Entities\Store;

class StoreRepository extends EloquentRepository implements CoreStoreRepository
{
    public function all(StoreQueryArgs $args)
    {
        return $this
            ->query($args)
            ->get();
    }

    public function count(StoreQueryArgs $args): int
    {
        return $this
            ->query($args)
            ->count();
    }

    public function findWhere(StoreQueryArgs $args): ?Store
    {
        return $this->query($args)->first();
    }

    public function query(StoreQueryArgs $args)
    {
        return Store::query()
            ->when($args->getSelect(), function ($query) use ($args) {
                $query->select($args->getSelect());
            })
            ->when($args->getWith(), function ($query) use ($args) {
                $query->with($args->getWith());
            })
            ->when($args->getWithCount(), function ($query) use ($args) {
                $query->withCount($args->getWithCount());
            })
            ->when($args->getSort(), function ($query) use ($args) {
                $query->orderBy($args->getSort(), $args->getOrder());
            })
            ->when($args->id, function ($query) use ($args) {
                $query->where('id', $args->id);
            })
            ->when($args->employee_id, function ($query) use ($args) {
                $query->whereHas('employees', function ($query) use ($args) {
                    $query->where('users.ID', $args->employee_id);
                });
            })
            ->when(Undefined::isNot($args->enabled), function ($query) use ($args) {
                $query->where('enabled', $args->enabled);
            })
            ->when($args->keyword, function ($query) use ($args) {
                $query->where('name', 'like', $args->keyword . '%');
            });
    }

    public function paginate(StoreQueryArgs $args)
    {
        return $this
            ->query($args)
            ->paginate($args->getPerpage(), $args->getSelect(), $args->getPageParam(), $args->getPage());
    }

    public function find(int $id): ?Store
    {
        return Store::find($id);
    }

    public function exists(int $id): bool
    {
        return Store::where('id', $id)->exists();
    }

    public function findOrCreateDefaultStore(): Store
    {
        $store = Store::query()->orderBy('id', 'asc')->first();

        if (!$store) {
            $store = posify_create_store([
                'name' => esc_html__('Default Store', 'posify-for-woocommerce'),
                'enabled' => true,
            ]);
        }

        return $store;
    }
}
