<?php

namespace Posify\Woocommerce\ServiceProviders;

use Posify\CustomerLicense\LicenseManager;
use Posify\Woocommerce\Utilities\HasInstance;

class AffiliateServiceProvider extends BaseServiceProvider
{
    use HasInstance;

    public static $affiliateCodeOptionKey = 'posify_affiliate_code';

    public function register()
    {
        add_action('posify_first_run_install', [$this, 'findAndSetAffiliateCode']);
        add_action('posify_save_license_key', [$this, 'setNewAffiliateCode']);
    }

    public function findAndSetAffiliateCode()
    {
        $filePath = POSIFY_HOME_DIR . '/affiliate.aff';

        $code = get_option(static::$affiliateCodeOptionKey, null);

        /**
         * We only update affiliate code when it never set before
         */
        if (file_exists($filePath) && !$code) {
            // phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
            $code = file_get_contents($filePath);
            update_option(static::$affiliateCodeOptionKey, $code);

            // Ensure import affiliate code only one
            wp_delete_file($filePath);
        }
    }

    public function setNewAffiliateCode()
    {
        $licenseInfo = LicenseManager::getInstance()->getLicense();
        $affiliateCode = $licenseInfo->getAffiliateCode();

        if ($affiliateCode) {
            update_option(static::$affiliateCodeOptionKey, $affiliateCode);
        }
    }
}
