<?php

namespace Posify\Woocommerce\ServiceProviders;

use Automattic\WooCommerce\Utilities\FeaturesUtil;
use Posify\Woocommerce\Utilities\HasInstance;

class PosifyServiceProvider extends BaseServiceProvider
{
    use HasInstance;

    protected $providers = [
        /**
         * License Service Provider must highest
         */
        LicenseServiceProvider::class,
        AffiliateServiceProvider::class,
        LanguageServiceProvider::class,
        DatabaseServiceProvider::class,
        RepositoryServiceProvider::class,
        EntityServiceProvider::class,
        InstallerServiceProvider::class,
        RestApiServiceProvider::class,
        PaymentServiceProvider::class,
        AuthServiceProvider::class,
        AdminServiceProvider::class,
        PosServiceProvider::class,
        PluginServiceProvider::class,
    ];

    public function register()
    {
        $this->markSupportHPOS();

        /**
         * Let's start the game
         */
        $this->start();
    }

    protected function start()
    {
        add_action('plugins_loaded', function () {
            if (!function_exists('WC')) {
                add_action('admin_notices', function () {
                    include_once POSIFY_HOME_DIR . '/resources/views/admin/install-woocommerce-notice.php';
                });
                return;
            }



            foreach ($this->providers as $provider) {
                $provider::instance()->register();
            }
        }, 11);
    }

    protected function markSupportHPOS()
    {
        add_action('before_woocommerce_init', function () {
            if (class_exists(FeaturesUtil::class)) {
                FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
            }
        });
    }
}
