<?php

namespace Posify\Woocommerce\UseCases;

use Posify\Woocommerce\Entities\Order;
use WC_Order;

class SyncOrder
{
    private Order $order;

    public WC_Order $wcOrder;

    public function __construct(
        WC_Order $wcOrder
    ) {
        $this->wcOrder = $wcOrder;
    }

    public static function make(WC_Order $wcOrder)
    {
        return new static($wcOrder);
    }

    public function execute()
    {
        $this->order = $this->syncOrder();
        $this->syncOrderPaymentGateways();
    }

    private function syncOrder(): Order
    {
        $orderData = [
            'register_id' => $this->wcOrder->get_meta('_posify_register_id'),
            'register_name' => $this->wcOrder->get_meta('_posify_register_name'),
            'cashier_id' => $this->wcOrder->get_meta('_posify_cashier_id'),
            'cashier_name' => $this->wcOrder->get_meta('_posify_cashier_name'),
            'register_session_id' => $this->wcOrder->get_meta('_posify_register_session_id'),
            'store_id' => $this->wcOrder->get_meta('_posify_store_id'),
            'store_name' => $this->wcOrder->get_meta('_posify_store_name'),
            'customer_id' => $this->wcOrder->get_customer_id(),
            'currency' => $this->wcOrder->get_currency(),
            'shipping_tax' => $this->wcOrder->get_shipping_tax(),
            'order_tax' => $this->wcOrder->get_total_tax(),
            'order_total' => $this->wcOrder->get_total(),
            'cart_discount' => $this->wcOrder->get_discount_total(),
            'cart_discount_tax' => $this->wcOrder->get_discount_tax(),
            'order_shipping' => $this->wcOrder->get_shipping_total(),
            'payment_method' => $this->wcOrder->get_payment_method(),
            'payment_method_title' => $this->wcOrder->get_payment_method_title(),
            'billing_first_name' => $this->wcOrder->get_billing_first_name(),
            'billing_last_name' => $this->wcOrder->get_billing_last_name(),
            'billing_company' => $this->wcOrder->get_billing_company(),
            'billing_address_1' => $this->wcOrder->get_billing_address_1(),
            'billing_address_2' => $this->wcOrder->get_billing_address_2(),
            'billing_city' => $this->wcOrder->get_billing_city(),
            'billing_state' => $this->wcOrder->get_billing_state(),
            'billing_postcode' => $this->wcOrder->get_billing_postcode(),
            'billing_country' => $this->wcOrder->get_billing_country(),
            'billing_email' => $this->wcOrder->get_billing_email(),
            'billing_phone' => $this->wcOrder->get_billing_phone(),
            'shipping_first_name' => $this->wcOrder->get_shipping_first_name(),
            'shipping_last_name' => $this->wcOrder->get_shipping_last_name(),
            'shipping_company' => $this->wcOrder->get_shipping_company(),
            'shipping_address_1' => $this->wcOrder->get_shipping_address_1(),
            'shipping_address_2' => $this->wcOrder->get_shipping_address_2(),
            'shipping_city' => $this->wcOrder->get_shipping_city(),
            'shipping_state' => $this->wcOrder->get_shipping_state(),
            'shipping_postcode' => $this->wcOrder->get_shipping_postcode(),
            'shipping_country' => $this->wcOrder->get_shipping_country(),
            'shipping_phone' => $this->wcOrder->get_shipping_phone(),
            'shipping_email' => $this->wcOrder->get_meta('_posify_shipping_email'),
            'total_items' => $this->wcOrder->get_item_count(),
            'total_paying' => (float) $this->wcOrder->get_meta('_posify_total_paying'),
            'total_balance' => (float) $this->wcOrder->get_meta('_posify_total_balance'),
            'total_change' => (float) $this->wcOrder->get_meta('_posify_total_change'),
        ];

        return Order::updateOrCreate([
            'id' => $this->wcOrder->get_id(),
        ], $orderData);
    }

    private function syncOrderPaymentGateways()
    {
        $paymentGateways = [];
        $wcOrderMetaData = $this->wcOrder->get_meta_data();

        foreach ($wcOrderMetaData as $metaData) {
            $metaKey = $metaData->key;
            $metaValue = $metaData->value;

            if (strpos($metaKey, '_posify_gateway_total_') === 0) {
                $paymentGatewayId = str_replace('_posify_gateway_total_', '', $metaKey);
                $paymentGatewayTitle = posify_wc_get_payment_gateway_title_by_id($paymentGatewayId);

                $paymentGateways[] = [
                    'payment_gateway_id' => $paymentGatewayId,
                    'payment_gateway_title' => $paymentGatewayTitle,
                    'amount' => $metaValue,
                ];
            }
        }

        $this->order->paymentGateways()->delete();
        $this->order->paymentGateways()->createMany($paymentGateways);
    }
}
