import { ai as getDefaultExportFromCjs, a4 as requestFactory, ak as defineStore, K as ref, d as defineComponent, f as useLanguageStore, g as computed, L as onMounted, r as resolveComponent, o as openBlock, a as createBlock, j as unref, T as Modal, bu as slug, N as watch, b2 as addressFactory, O as withCtx, p as createVNode, aR as mergeProps, aP as Form, i as createBaseVNode, t as toDisplayString, b as createCommentVNode } from "./index.uaDs3xEUfw.js";
import { _ as _baseIsEqual } from "./_baseIsEqual.uaDs3xEUfw.js";
import { b as addressRulesFactory } from "./address.uaDs3xEUfw.js";
import { _ as _sfc_main$4 } from "./ScrollPanel.vue_vue_type_script_setup_true_lang.uaDs3xEUfw.js";
var baseIsEqual = _baseIsEqual;
function isEqual(value, other) {
  return baseIsEqual(value, other);
}
var isEqual_1 = isEqual;
const isEqual$1 = /* @__PURE__ */ getDefaultExportFromCjs(isEqual_1);
const objectIsEqual = isEqual$1;
const useCountryApi = async () => await requestFactory("country");
const useCountryStore = defineStore(
  "useCountryStore",
  () => {
    const items = ref([]);
    const fetch = async () => {
      const countryApi = await useCountryApi();
      let hasError = false, errorCode = null, errorMessage = null, errorDetails = null;
      try {
        const { data } = await countryApi.getList({
          enabled: true
        });
        items.value = data;
      } catch (error) {
        console.error(error);
        hasError = true;
        errorCode = error.posifyError.code;
        errorMessage = error.posifyError.message;
        errorDetails = error.posifyError.details;
      }
      return {
        hasError,
        errorCode,
        errorMessage,
        errorDetails
      };
    };
    return {
      items,
      fetch
    };
  },
  {
    persist: true
  }
);
const _sfc_main$3 = /* @__PURE__ */ defineComponent({
  __name: "CountrySelect",
  props: {
    value: {
      type: [Number, String]
    }
  },
  emits: ["update:value", "change"],
  setup(__props, { emit }) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const countryStore = useCountryStore();
    const countries = computed(() => {
      return countryStore.items.map((country) => ({
        value: country.code,
        label: country.name
      }));
    });
    onMounted(() => {
      const f = async () => {
        const { hasError, errorMessage, errorDetails } = await countryStore.fetch();
        if (hasError) {
          Modal.error({
            title: errorMessage,
            content: JSON.stringify(errorDetails)
          });
          return;
        }
      };
      f();
    });
    const filterCountries = (input, option) => {
      return slug(option.label).toLowerCase().indexOf(slug(input).toLowerCase()) >= 0;
    };
    const handleChange = (countryId) => {
      emit("update:value", countryId);
      emit("change", countryId);
    };
    return (_ctx, _cache) => {
      const _component_a_select = resolveComponent("a-select");
      return openBlock(), createBlock(_component_a_select, {
        value: __props.value,
        "show-search": "",
        placeholder: unref(__)("Select a country"),
        class: "tw-w-full",
        ref: "select",
        options: countries.value,
        "filter-option": filterCountries,
        "allow-clear": "",
        onChange: handleChange
      }, null, 8, ["value", "placeholder", "options"]);
    };
  }
});
const _sfc_main$2 = /* @__PURE__ */ defineComponent({
  __name: "StateInput",
  props: {
    value: {
      type: [Number, String]
    },
    countryCode: {
      type: String
    }
  },
  emits: ["update:value", "change", "input"],
  setup(__props, { emit }) {
    const props = __props;
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const inputControl = computed(
      () => {
        var _a;
        return ((_a = states.value) == null ? void 0 : _a.length) ? "select" : "input";
      }
    );
    const states = ref([]);
    const fetching = ref(false);
    const fetchSates = async () => {
      if (!props.countryCode) {
        return;
      }
      states.value = [];
      fetching.value = true;
      const countryApi = await useCountryApi();
      countryApi.getDetail(props.countryCode).then(({ data }) => {
        var _a;
        states.value = (_a = data.states) == null ? void 0 : _a.map((state) => ({
          value: state.code,
          label: state.name
        }));
      }).finally(() => fetching.value = false);
    };
    fetchSates();
    watch(
      () => props.countryCode,
      () => fetchSates()
    );
    const filterStates = (input, option) => {
      return slug(option.label).toLowerCase().indexOf(slug(input).toLowerCase()) >= 0;
    };
    const handleChange = (stateCode) => {
      emit("update:value", stateCode);
      emit("change", stateCode);
      emit("input", stateCode);
    };
    return (_ctx, _cache) => {
      const _component_a_select = resolveComponent("a-select");
      const _component_a_input = resolveComponent("a-input");
      return inputControl.value == "select" ? (openBlock(), createBlock(_component_a_select, {
        key: 0,
        value: __props.value,
        "show-search": "",
        placeholder: unref(__)("Select a country"),
        class: "tw-w-full",
        ref: "select",
        options: states.value,
        "filter-option": filterStates,
        loading: fetching.value,
        "allow-clear": "",
        onChange: handleChange
      }, null, 8, ["value", "placeholder", "options", "loading"])) : (openBlock(), createBlock(_component_a_input, {
        key: 1,
        value: __props.value,
        onInput: _cache[0] || (_cache[0] = ($event) => handleChange($event.target.value))
      }, null, 8, ["value"]));
    };
  }
});
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "AddressFields",
  props: {
    formState: {
      type: Object,
      default() {
        return addressFactory();
      }
    },
    validateInfos: {
      type: Object,
      default() {
        return addressFactory();
      }
    },
    fieldGroup: {
      type: String,
      default: ""
    },
    autofocus: {
      type: Boolean,
      default: false
    }
  },
  emits: ["change", "update:form-state"],
  setup(__props, { emit }) {
    const props = __props;
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const firstInputRef = ref();
    onMounted(() => {
      if (!props.autofocus) {
        return;
      }
      setTimeout(() => {
        var _a;
        (_a = firstInputRef == null ? void 0 : firstInputRef.value) == null ? void 0 : _a.focus();
      }, 100);
    });
    const handleChangeFormState = (key, value) => {
      const emitPayload = {
        ...props.formState,
        ...{ [key]: value }
      };
      emit("update:form-state", emitPayload);
      emit("change", emitPayload);
    };
    return (_ctx, _cache) => {
      const _component_a_input = resolveComponent("a-input");
      const _component_a_form_item = resolveComponent("a-form-item");
      const _component_a_col = resolveComponent("a-col");
      const _component_a_row = resolveComponent("a-row");
      return openBlock(), createBlock(_component_a_row, { gutter: [18, 0] }, {
        default: withCtx(() => [
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("First name")
              }, __props.validateInfos[`${__props.fieldGroup}.firstName`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.firstName,
                    ref_key: "firstInputRef",
                    ref: firstInputRef,
                    onInput: _cache[0] || (_cache[0] = ($event) => handleChangeFormState("firstName", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Last name")
              }, __props.validateInfos[`${__props.fieldGroup}.lastName`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.lastName,
                    onChange: _cache[1] || (_cache[1] = ($event) => handleChangeFormState("lastName", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Phone")
              }, __props.validateInfos[`${__props.fieldGroup}.phone`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.phone,
                    onChange: _cache[2] || (_cache[2] = ($event) => handleChangeFormState("phone", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Company")
              }, __props.validateInfos[`${__props.fieldGroup}.company`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.company,
                    onChange: _cache[3] || (_cache[3] = ($event) => handleChangeFormState("company", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Email")
              }, __props.validateInfos[`${__props.fieldGroup}.email`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.email,
                    onChange: _cache[4] || (_cache[4] = ($event) => handleChangeFormState("email", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, { span: 24 }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Address %d", [1])
              }, __props.validateInfos[`${__props.fieldGroup}.address1`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.address1,
                    onChange: _cache[5] || (_cache[5] = ($event) => handleChangeFormState("address1", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, { span: 24 }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Address %d", [2])
              }, __props.validateInfos[`${__props.fieldGroup}.address2`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.address2,
                    onChange: _cache[6] || (_cache[6] = ($event) => handleChangeFormState("address2", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("City")
              }, __props.validateInfos[`${__props.fieldGroup}.city`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.city,
                    onChange: _cache[7] || (_cache[7] = ($event) => handleChangeFormState("city", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Post code")
              }, __props.validateInfos[`${__props.fieldGroup}.postcode`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_component_a_input, {
                    value: __props.formState.postcode,
                    onChange: _cache[8] || (_cache[8] = ($event) => handleChangeFormState("postcode", $event.target.value))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("Country")
              }, __props.validateInfos[`${__props.fieldGroup}.country`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_sfc_main$3, {
                    value: __props.formState.country,
                    onChange: _cache[9] || (_cache[9] = (v) => handleChangeFormState("country", v))
                  }, null, 8, ["value"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          }),
          createVNode(_component_a_col, {
            xs: 24,
            md: 8
          }, {
            default: withCtx(() => [
              createVNode(_component_a_form_item, mergeProps({
                label: unref(__)("State")
              }, __props.validateInfos[`${__props.fieldGroup}.state`], { class: "address-form__form-item" }), {
                default: withCtx(() => [
                  createVNode(_sfc_main$2, {
                    value: __props.formState.state,
                    "country-code": __props.formState.country,
                    onChange: _cache[10] || (_cache[10] = (v) => handleChangeFormState("state", v))
                  }, null, 8, ["value", "country-code"])
                ]),
                _: 1
              }, 16, ["label"])
            ]),
            _: 1
          })
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1 = { class: "tw-flex tw-mb-4" };
const _hoisted_2 = { class: "tw-font-semibold tw-mr-2" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "AddressForm",
  props: {
    billingSameShipping: {
      type: Boolean,
      default: false
    },
    shippingAddress: {
      type: Object,
      default() {
        return addressFactory();
      }
    },
    billingAddress: {
      type: Object,
      default() {
        return addressFactory();
      }
    },
    requiredShippingAddressEmail: {
      type: Boolean,
      default: false
    },
    uniqueShippingAddressEmail: {
      type: Boolean,
      default: false
    },
    checkEmailUniqueCallback: {
      type: Function,
      default: () => {
      }
    }
  },
  emits: [
    "setup",
    "submit",
    "update:billing-same-shipping",
    "update:shipping-address",
    "update:billing-address"
  ],
  setup(__props, { emit }) {
    const props = __props;
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const addressFormRef = ref();
    const formState = computed(() => ({
      shippingAddress: addressFactory(props.shippingAddress),
      billingAddress: addressFactory(props.billingAddress)
    }));
    const formValidationRules = computed(() => {
      const shippingAddressRules = addressRulesFactory("shippingAddress");
      let shippingAddressEmailRules = [];
      if (props.requiredShippingAddressEmail) {
        shippingAddressEmailRules.push({
          required: true,
          message: __("Please input email")
        });
      }
      if (props.uniqueShippingAddressEmail) {
        shippingAddressEmailRules = [];
        shippingAddressEmailRules.push({
          type: "email",
          validator: props.checkEmailUniqueCallback
        });
      }
      if (shippingAddressEmailRules) {
        shippingAddressRules["shippingAddress.email"] = shippingAddressEmailRules;
      }
      return {
        ...shippingAddressRules,
        ...props.billingSameShipping ? {} : addressRulesFactory("billingAddress")
      };
    });
    const { validate, validateInfos } = Form.useForm(
      formState,
      formValidationRules
    );
    emit("setup", { validate });
    const handleChangeSwitchBillingSameShipping = (checked) => {
      emit("update:billing-same-shipping", checked);
    };
    const handleChangeShippingForm = (shippingAddress) => {
      emit("update:shipping-address", shippingAddress);
    };
    const handleChangeBillingForm = (billingAddress) => {
      emit("update:billing-address", billingAddress);
    };
    return (_ctx, _cache) => {
      const _component_a_switch = resolveComponent("a-switch");
      const _component_a_form = resolveComponent("a-form");
      return openBlock(), createBlock(_component_a_form, {
        ref_key: "addressFormRef",
        ref: addressFormRef,
        layout: "vertical",
        model: formState.value,
        "wrapper-col": { span: 24 },
        class: "address-form",
        onSubmit: _cache[0] || (_cache[0] = ($event) => emit("submit"))
      }, {
        default: withCtx(() => [
          createVNode(_sfc_main$4, { class: "address-modal-body" }, {
            default: withCtx(() => [
              createVNode(_sfc_main$1, {
                key: "shippingAddress",
                "form-state": formState.value.shippingAddress,
                "validate-infos": unref(validateInfos),
                autofocus: "",
                "field-group": "shippingAddress",
                onChange: handleChangeShippingForm
              }, null, 8, ["form-state", "validate-infos"]),
              createBaseVNode("div", _hoisted_1, [
                createBaseVNode("div", _hoisted_2, toDisplayString(unref(__)("Billing use the same info for shipping")), 1),
                createVNode(_component_a_switch, {
                  checked: __props.billingSameShipping,
                  "checked-children": unref(__)("Yes"),
                  "un-checked-children": unref(__)("No"),
                  onChange: handleChangeSwitchBillingSameShipping
                }, null, 8, ["checked", "checked-children", "un-checked-children"])
              ]),
              !__props.billingSameShipping ? (openBlock(), createBlock(_sfc_main$1, {
                key: "billingAddress",
                "form-state": formState.value.billingAddress,
                "validate-Infos": unref(validateInfos),
                "field-group": "billingAddress",
                onChange: handleChangeBillingForm
              }, null, 8, ["form-state", "validate-Infos"])) : createCommentVNode("", true)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["model"]);
    };
  }
});
const AddressForm_vue_vue_type_style_index_0_lang = "";
export {
  _sfc_main as _,
  objectIsEqual as o
};
