import { d as defineComponent, f as useLanguageStore, K as ref, bm as useCustomerApi, aq as fullName, T as Modal, N as watch, L as onMounted, r as resolveComponent, o as openBlock, a as createBlock, an as createSlots, O as withCtx, p as createVNode, j as unref, G as useCartCustomerStore, H as useCustomerModalStore, s as storeToRefs, c as createElementBlock, t as toDisplayString, i as createBaseVNode, bn as faUserSecret, J as createTextVNode, aK as withModifiers, bo as faUserPlus, bp as isValidEmail } from "./index.uaDs3xEUfw.js";
import { d as debounce } from "./debounce.uaDs3xEUfw.js";
import { _ as _sfc_main$2 } from "./CustomerSummary.vue_vue_type_script_setup_true_lang.uaDs3xEUfw.js";
import { _ as _export_sfc } from "./_plugin-vue_export-helper.uaDs3xEUfw.js";
const SEARCH_MIN_LENGTH = 3;
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "CustomerSelect",
  props: {
    value: {
      type: [Number, String]
    }
  },
  emits: [
    "update:value",
    "change",
    "search-warning",
    "search"
  ],
  setup(__props, { emit }) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const rawData = ref([]);
    const customers = ref([]);
    const fetching = ref(false);
    const warning = ref("");
    const customerSelectRef = ref();
    const fetchCustomers = debounce(async (search = "") => {
      customers.value = [];
      warning.value = "";
      const customerApi = await useCustomerApi();
      if (search.length > 2) {
        emit("search", search);
        fetching.value = true;
        customerApi.getList({ search }).then(({ data }) => {
          if (data.length == 0) {
            warning.value = __("Customer not found");
          }
          rawData.value = data;
          customers.value = data.map((customer) => ({
            value: customer.id,
            label: fullName({
              firstName: customer.firstName,
              lastName: customer.lastName
            }),
            email: customer.email,
            avatarUrl: customer.avatarUrl,
            phone: customer.phone,
            firstName: customer.firstName,
            lastName: customer.lastName
          }));
        }).catch((error) => {
          var _a;
          console.error(error);
          Modal.error({
            title: __("Load report data unsuccessfully"),
            content: JSON.stringify((_a = error == null ? void 0 : error.posifyError) == null ? void 0 : _a.details)
          });
        }).finally(() => fetching.value = false);
      }
      if (search.length > 0 && search.length < SEARCH_MIN_LENGTH) {
        warning.value = __("Should enter at least %s characters", [
          SEARCH_MIN_LENGTH
        ]);
      }
    }, 300);
    fetchCustomers();
    const handleChange = (customerId) => {
      emit("update:value", customerId);
      const customerInfo = rawData.value.find(
        (customer) => customer.id == customerId
      );
      emit("change", customerInfo);
    };
    watch(warning, () => emit("search-warning", warning.value));
    onMounted(() => {
      setTimeout(() => {
        var _a;
        return (_a = customerSelectRef == null ? void 0 : customerSelectRef.value) == null ? void 0 : _a.focus();
      }, 100);
    });
    return (_ctx, _cache) => {
      const _component_a_spin = resolveComponent("a-spin");
      const _component_a_select = resolveComponent("a-select");
      return openBlock(), createBlock(_component_a_select, {
        value: __props.value,
        "show-search": "",
        placeholder: unref(__)("Enter customer email to search"),
        class: "tw-w-full",
        ref_key: "customerSelectRef",
        ref: customerSelectRef,
        "allow-clear": "",
        options: customers.value,
        "filter-option": false,
        "not-found-content": fetching.value ? void 0 : null,
        onSearch: unref(fetchCustomers),
        onChange: handleChange
      }, createSlots({
        option: withCtx((customer) => [
          createVNode(_sfc_main$2, { customer }, null, 8, ["customer"])
        ]),
        _: 2
      }, [
        fetching.value ? {
          name: "notFoundContent",
          fn: withCtx(() => [
            createVNode(_component_a_spin, { size: "small" })
          ]),
          key: "0"
        } : void 0
      ]), 1032, ["value", "placeholder", "options", "not-found-content", "onSearch"]);
    };
  }
});
const _hoisted_1 = {
  key: 0,
  class: "tw-text-negative"
};
const _hoisted_2 = { key: 1 };
const _hoisted_3 = { class: "tw-font-semibold tw-mt-4 tw-text-center" };
const _hoisted_4 = { class: "buttons-container" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "LoadCustomerProfile",
  setup(__props) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const cartCustomerStore = useCartCustomerStore();
    const customerModalStore = useCustomerModalStore();
    const { section } = storeToRefs(customerModalStore);
    const searchWarning = ref("");
    const customerSearch = ref("");
    const handleChangeSelectCustomer = (customerInfo) => {
      customerModalStore.updateCustomer(customerInfo);
      customerModalStore.updateCustomerBilling(customerInfo.billing);
      customerModalStore.updateCustomerShipping(customerInfo.shipping);
      section.value = "preview_customer_info";
    };
    const handleClickCreateCustomerProfile = () => {
      section.value = "customer_creation_form";
      if (customerSearch.value && isValidEmail(customerSearch.value)) {
        customerModalStore.setCustomerEmail(customerSearch.value);
      }
    };
    const handleSearchWarning = (value) => {
      searchWarning.value = value;
    };
    const handleClickProceedCustomerAsGuest = () => {
      cartCustomerStore.proceedAsGuest();
      customerModalStore.clearCustomer();
      section.value = "select_customer_type";
      customerModalStore.hide();
    };
    const handleSearch = (value) => {
      customerSearch.value = value;
    };
    return (_ctx, _cache) => {
      const _component_a_divider = resolveComponent("a-divider");
      const _component_font_awesome_icon = resolveComponent("font-awesome-icon");
      const _component_a_button = resolveComponent("a-button");
      return openBlock(), createElementBlock("div", null, [
        createVNode(_sfc_main$1, {
          onChange: handleChangeSelectCustomer,
          onSearchWarning: handleSearchWarning,
          onSearch: handleSearch
        }),
        createVNode(_component_a_divider, null, {
          default: withCtx(() => [
            searchWarning.value ? (openBlock(), createElementBlock("span", _hoisted_1, toDisplayString(searchWarning.value), 1)) : (openBlock(), createElementBlock("span", _hoisted_2, toDisplayString(unref(__)("OR")), 1))
          ]),
          _: 1
        }),
        createBaseVNode("div", _hoisted_3, [
          createBaseVNode("div", _hoisted_4, [
            createVNode(_component_a_button, {
              onClick: withModifiers(handleClickProceedCustomerAsGuest, ["prevent"]),
              class: "customer-button"
            }, {
              icon: withCtx(() => [
                createVNode(_component_font_awesome_icon, {
                  icon: unref(faUserSecret),
                  class: "tw-mr-2 tw-text-lg"
                }, null, 8, ["icon"])
              ]),
              default: withCtx(() => [
                createTextVNode(" " + toDisplayString(unref(__)("Proceed as guest")), 1)
              ]),
              _: 1
            }, 8, ["onClick"]),
            createVNode(_component_a_button, {
              onClick: withModifiers(handleClickCreateCustomerProfile, ["prevent"]),
              class: "customer-button"
            }, {
              icon: withCtx(() => [
                createVNode(_component_font_awesome_icon, {
                  icon: unref(faUserPlus),
                  class: "tw-mr-2 tw-text-lg"
                }, null, 8, ["icon"])
              ]),
              default: withCtx(() => [
                createTextVNode(" " + toDisplayString(unref(__)("Create new customer")), 1)
              ]),
              _: 1
            }, 8, ["onClick"])
          ])
        ])
      ]);
    };
  }
});
const LoadCustomerProfile_vue_vue_type_style_index_0_scoped_253857b8_lang = "";
const LoadCustomerProfile = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-253857b8"]]);
export {
  LoadCustomerProfile as default
};
