import { d as defineComponent, f as useLanguageStore, K as ref, r as resolveComponent, o as openBlock, a as createBlock, j as unref, as as usePermissionStore, s as storeToRefs, k as usePosStore, m as useCommonModalsStore, l as useCartItemStore, aP as Form, O as withCtx, p as createVNode, J as createTextVNode, t as toDisplayString, b as createCommentVNode, aR as mergeProps, c as createElementBlock, F as Fragment, T as Modal, aL as priceBeforeTax, b1 as useProductApi, V as message } from "./index.uaDs3xEUfw.js";
import { _ as _sfc_main$2, a as _sfc_main$3 } from "./TaxStatusSelect.vue_vue_type_script_setup_true_lang.uaDs3xEUfw.js";
import { u as useCategoryApi } from "./category.uaDs3xEUfw.js";
import { d as defaultImage } from "./product-placeholder.uaDs3xEUfw.js";
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "ProductCategorySelect",
  props: {
    value: {
      type: [Number, String]
    }
  },
  emits: ["update:value", "change"],
  setup(__props, { emit }) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const categories = ref([]);
    const fetching = ref(false);
    const fetchCategories = async () => {
      categories.value = [];
      fetching.value = true;
      const categoryApi = await useCategoryApi();
      categoryApi.getList().then(({ data }) => {
        categories.value = data.map((category) => ({
          value: category.id,
          label: category.title
        }));
      }).finally(() => fetching.value = false);
    };
    fetchCategories();
    const filterCategories = (input, option) => {
      return option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0;
    };
    const handleChange = (categoryId) => {
      emit("update:value", categoryId);
      emit("change", categoryId);
    };
    return (_ctx, _cache) => {
      const _component_a_select = resolveComponent("a-select");
      return openBlock(), createBlock(_component_a_select, {
        value: __props.value,
        "show-search": "",
        placeholder: unref(__)("Select a category"),
        class: "tw-w-full",
        ref: "select",
        options: categories.value,
        "filter-option": filterCategories,
        loading: fetching.value,
        onChange: handleChange
      }, null, 8, ["value", "placeholder", "options", "loading"]);
    };
  }
});
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "ProductCreationModal",
  setup(__props) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const permissionStore = usePermissionStore();
    const { canCreateProduct } = storeToRefs(permissionStore);
    const posStore = usePosStore();
    const commonModalsStore = useCommonModalsStore();
    const cartItemStore = useCartItemStore();
    const isCreatingProduct = ref(false);
    const formRef = ref();
    const formState = ref({
      syncWithManagementTool: 1,
      productTitle: "",
      productRegularPrice: "",
      taxStatus: posStore.register.defaultTaxStatus,
      taxClass: posStore.register.defaultTaxClass,
      categoryId: "",
      sku: "",
      manageStock: 0,
      stockQuantity: ""
    });
    const { resetFields, validate, validateInfos } = Form.useForm(
      formState,
      ref({
        productTitle: [
          {
            required: true,
            message: __("Please input product title")
          }
        ],
        productRegularPrice: [
          {
            required: true,
            message: __("Please input regular price")
          }
        ],
        syncWithManagementTool: [],
        taxStatus: [],
        taxClass: [],
        categoryId: [],
        sku: [],
        manageStock: [],
        stockQuantity: []
      })
    );
    const syncWithManagementToolOptions = [
      { value: 0, label: __("Disabled") },
      { value: 1, label: __("Enabled") }
    ];
    const manageStockOptions = [
      { value: 0, label: __("Disabled") },
      { value: 1, label: __("Enabled") }
    ];
    const syncProductToManagementTool = async (productData) => {
      isCreatingProduct.value = true;
      let hasError, errorCode, errorMessage, errorDetails, successData;
      const productApi = await useProductApi();
      try {
        const { data } = await productApi.create({
          title: productData.productTitle,
          regularPrice: productData.productRegularPrice,
          taxStatus: productData.taxStatus,
          taxClass: productData.taxClass,
          categoryId: productData.categoryId,
          sku: productData.sku,
          manageStock: productData.manageStock,
          stockQuantity: productData.stockQuantity
        });
        successData = data;
        message.success(__("Create product successfully"));
      } catch (error) {
        console.error(error);
        hasError = true;
        errorCode = error.posifyError.code;
        errorMessage = error.posifyError.message;
        errorDetails = error.posifyError.details;
      }
      isCreatingProduct.value = false;
      return {
        hasError,
        errorCode,
        errorMessage,
        errorDetails,
        successData
      };
    };
    const handleFinishForm = () => {
      validate().then(async (productData) => {
        let productId = "product:" + Math.random().toString(36).slice(2);
        const { syncWithManagementTool, productTitle } = productData;
        if (canCreateProduct.value && syncWithManagementTool) {
          const { hasError, errorDetails, successData } = await syncProductToManagementTool(productData);
          if (hasError) {
            Modal.error({
              title: __("Create product unsuccessfully"),
              content: JSON.stringify(errorDetails)
            });
            return;
          }
          productId = successData.id;
        }
        cartItemStore.add({
          productTitle,
          productId,
          variationId: void 0,
          price: priceBeforeTax(productData, "productRegularPrice"),
          regularPrice: priceBeforeTax(productData, "productRegularPrice"),
          thumbnail: defaultImage,
          options: void 0,
          manageStock: false,
          stockQuantity: null,
          taxClass: productData.taxClass,
          taxStatus: productData.taxStatus
        });
        commonModalsStore.hideProductCreationModal();
      });
    };
    const handleFinishFormFailed = () => {
      console.log("handleFinishFormFailed");
    };
    const clearState = () => {
      resetFields({
        syncWithManagementTool: 0,
        productTitle: "",
        productRegularPrice: "",
        taxStatus: "",
        taxClass: "",
        categoryId: "",
        sku: "",
        manageStock: 0,
        stockQuantity: ""
      });
    };
    const handleCancelModel = () => {
      clearState();
      commonModalsStore.hideProductCreationModal();
    };
    return (_ctx, _cache) => {
      const _component_a_select = resolveComponent("a-select");
      const _component_a_form_item = resolveComponent("a-form-item");
      const _component_a_col = resolveComponent("a-col");
      const _component_a_input = resolveComponent("a-input");
      const _component_a_input_number = resolveComponent("a-input-number");
      const _component_a_row = resolveComponent("a-row");
      const _component_a_form = resolveComponent("a-form");
      const _component_a_button = resolveComponent("a-button");
      const _component_a_modal = resolveComponent("a-modal");
      return openBlock(), createBlock(_component_a_modal, {
        title: unref(__)("Add new product"),
        visible: unref(commonModalsStore).productCreationModal.visible,
        "onUpdate:visible": _cache[9] || (_cache[9] = ($event) => unref(commonModalsStore).productCreationModal.visible = $event),
        width: "740px",
        onOk: unref(commonModalsStore).hideProductCreationModal,
        onCancel: handleCancelModel
      }, {
        footer: withCtx(() => [
          createVNode(_component_a_button, {
            key: "back",
            onClick: handleCancelModel
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString(unref(__)("Close")), 1)
            ]),
            _: 1
          }),
          createVNode(_component_a_button, {
            key: "submit",
            type: "primary",
            loading: isCreatingProduct.value,
            onClick: handleFinishForm
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString(unref(__)("Create product")), 1)
            ]),
            _: 1
          }, 8, ["loading"])
        ]),
        default: withCtx(() => [
          createVNode(_component_a_form, {
            layout: "vertical",
            model: formState.value,
            ref: formRef.value,
            "wrapper-col": { span: 24 },
            class: "product-creation-form",
            onFinish: handleFinishForm,
            onFinishFailed: handleFinishFormFailed
          }, {
            default: withCtx(() => [
              createVNode(_component_a_row, { gutter: [18, 0] }, {
                default: withCtx(() => [
                  unref(canCreateProduct) ? (openBlock(), createBlock(_component_a_col, {
                    key: 0,
                    xs: 24,
                    md: 8
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_a_form_item, {
                        label: unref(__)("Sync to management system"),
                        class: "product-creation-form__form-item"
                      }, {
                        default: withCtx(() => [
                          createVNode(_component_a_select, {
                            ref: "select",
                            value: formState.value.syncWithManagementTool,
                            "onUpdate:value": _cache[0] || (_cache[0] = ($event) => formState.value.syncWithManagementTool = $event),
                            class: "tw-w-full",
                            options: syncWithManagementToolOptions
                          }, null, 8, ["value"])
                        ]),
                        _: 1
                      }, 8, ["label"])
                    ]),
                    _: 1
                  })) : createCommentVNode("", true),
                  createVNode(_component_a_col, {
                    xs: 24,
                    md: 8
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_a_form_item, mergeProps({
                        label: unref(__)("Product title")
                      }, unref(validateInfos).productTitle, { class: "product-creation-form__form-item" }), {
                        default: withCtx(() => [
                          createVNode(_component_a_input, {
                            value: formState.value.productTitle,
                            "onUpdate:value": _cache[1] || (_cache[1] = ($event) => formState.value.productTitle = $event)
                          }, null, 8, ["value"])
                        ]),
                        _: 1
                      }, 16, ["label"])
                    ]),
                    _: 1
                  }),
                  createVNode(_component_a_col, {
                    xs: 24,
                    md: 8
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_a_form_item, mergeProps({
                        label: unref(__)("Regular price")
                      }, unref(validateInfos).productRegularPrice, { class: "product-creation-form__form-item" }), {
                        default: withCtx(() => [
                          createVNode(_component_a_input_number, {
                            value: formState.value.productRegularPrice,
                            "onUpdate:value": _cache[2] || (_cache[2] = ($event) => formState.value.productRegularPrice = $event),
                            class: "tw-w-full",
                            min: 1
                          }, null, 8, ["value"])
                        ]),
                        _: 1
                      }, 16, ["label"])
                    ]),
                    _: 1
                  }),
                  createVNode(_component_a_col, {
                    xs: 24,
                    md: 8
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_a_form_item, {
                        label: unref(__)("Tax status"),
                        class: "product-creation-form__form-item"
                      }, {
                        default: withCtx(() => [
                          createVNode(_sfc_main$2, {
                            value: formState.value.taxStatus,
                            "onUpdate:value": _cache[3] || (_cache[3] = ($event) => formState.value.taxStatus = $event)
                          }, null, 8, ["value"])
                        ]),
                        _: 1
                      }, 8, ["label"])
                    ]),
                    _: 1
                  }),
                  createVNode(_component_a_col, {
                    xs: 24,
                    md: 8
                  }, {
                    default: withCtx(() => [
                      createVNode(_component_a_form_item, {
                        label: unref(__)("Tax class"),
                        class: "product-creation-form__form-item"
                      }, {
                        default: withCtx(() => [
                          createVNode(_sfc_main$3, {
                            value: formState.value.taxClass,
                            "onUpdate:value": _cache[4] || (_cache[4] = ($event) => formState.value.taxClass = $event)
                          }, null, 8, ["value"])
                        ]),
                        _: 1
                      }, 8, ["label"])
                    ]),
                    _: 1
                  }),
                  formState.value.syncWithManagementTool ? (openBlock(), createElementBlock(Fragment, { key: 1 }, [
                    createVNode(_component_a_col, {
                      xs: 24,
                      md: 8
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_form_item, {
                          label: unref(__)("Product category"),
                          class: "product-creation-form__form-item"
                        }, {
                          default: withCtx(() => [
                            createVNode(_sfc_main$1, {
                              value: formState.value.categoryId,
                              "onUpdate:value": _cache[5] || (_cache[5] = ($event) => formState.value.categoryId = $event)
                            }, null, 8, ["value"])
                          ]),
                          _: 1
                        }, 8, ["label"])
                      ]),
                      _: 1
                    }),
                    createVNode(_component_a_col, {
                      xs: 24,
                      md: 8
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_form_item, {
                          label: unref(__)("SKU"),
                          class: "product-creation-form__form-item"
                        }, {
                          default: withCtx(() => [
                            createVNode(_component_a_input, {
                              value: formState.value.sku,
                              "onUpdate:value": _cache[6] || (_cache[6] = ($event) => formState.value.sku = $event)
                            }, null, 8, ["value"])
                          ]),
                          _: 1
                        }, 8, ["label"])
                      ]),
                      _: 1
                    }),
                    createVNode(_component_a_col, {
                      xs: 24,
                      md: 8
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_form_item, {
                          label: unref(__)("Stock"),
                          class: "product-creation-form__form-item"
                        }, {
                          default: withCtx(() => [
                            createVNode(_component_a_select, {
                              ref: "select",
                              value: formState.value.manageStock,
                              "onUpdate:value": _cache[7] || (_cache[7] = ($event) => formState.value.manageStock = $event),
                              class: "tw-w-full",
                              options: manageStockOptions
                            }, null, 8, ["value"])
                          ]),
                          _: 1
                        }, 8, ["label"])
                      ]),
                      _: 1
                    }),
                    formState.value.manageStock ? (openBlock(), createBlock(_component_a_col, {
                      key: 0,
                      xs: 24,
                      md: 8
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_form_item, {
                          label: unref(__)("Quantity in stock"),
                          class: "product-creation-form__form-item"
                        }, {
                          default: withCtx(() => [
                            createVNode(_component_a_input_number, {
                              value: formState.value.stockQuantity,
                              "onUpdate:value": _cache[8] || (_cache[8] = ($event) => formState.value.stockQuantity = $event),
                              class: "tw-w-full",
                              min: 1
                            }, null, 8, ["value"])
                          ]),
                          _: 1
                        }, 8, ["label"])
                      ]),
                      _: 1
                    })) : createCommentVNode("", true)
                  ], 64)) : createCommentVNode("", true)
                ]),
                _: 1
              })
            ]),
            _: 1
          }, 8, ["model"])
        ]),
        _: 1
      }, 8, ["title", "visible", "onOk"]);
    };
  }
});
const ProductCreationModal_vue_vue_type_style_index_0_lang = "";
export {
  _sfc_main as default
};
