import { d as defineComponent, K as ref, g as computed, aT as onBeforeUnmount, L as onMounted, o as openBlock, c as createElementBlock, i as createBaseVNode, e as renderSlot, aU as pushScopeId, aV as popScopeId, f as useLanguageStore, m as useCommonModalsStore, N as watch, r as resolveComponent, a as createBlock, O as withCtx, p as createVNode, J as createTextVNode, t as toDisplayString, j as unref, b as createCommentVNode } from "./index.uaDs3xEUfw.js";
import { u as useProductSearch } from "./productSearch.uaDs3xEUfw.js";
import { _ as _export_sfc } from "./_plugin-vue_export-helper.uaDs3xEUfw.js";
const _withScopeId = (n) => (pushScopeId("data-v-05fd75fc"), n = n(), popScopeId(), n);
const _hoisted_1$1 = { class: "video__container" };
const _hoisted_2 = { class: "video__header" };
const _hoisted_3 = /* @__PURE__ */ _withScopeId(() => /* @__PURE__ */ createBaseVNode("div", { class: "scan-area" }, null, -1));
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "BarcodeScannerVideo",
  props: {
    accuracyLevel: {
      type: Number,
      default: 5
    }
  },
  emits: ["no-support", "detected", "stop"],
  setup(__props, { expose: __expose, emit }) {
    const props = __props;
    const video = ref();
    const scanning = ref(true);
    const videoStream = ref(null);
    const resultSets = ref({});
    const setScanning = (value) => {
      scanning.value = value;
    };
    const totalScan = computed(() => {
      let total = 0;
      for (const value of Object.values(resultSets.value)) {
        total = total + Number(value);
      }
      return total;
    });
    const handleDetected = (barCodes) => {
      if (totalScan.value < props.accuracyLevel) {
        for (const barCode of barCodes) {
          const code = barCode.rawValue;
          resultSets.value[code] = resultSets.value[code] ?? 0;
          resultSets.value[code]++;
        }
      } else {
        let maxCode, max;
        for (const code in resultSets.value) {
          if (!maxCode) {
            maxCode = code;
          }
          if (!max) {
            max = resultSets.value[code];
          }
          if (resultSets.value[code] > max) {
            maxCode = code;
            max = resultSets.value[code];
          }
          emit("detected", maxCode);
          resultSets.value = {};
        }
      }
    };
    const initBarcodeScanner = async () => {
      if (typeof BarcodeDetector === "undefined") {
        emit("no-support");
        return;
      }
      resultSets.value = {};
      try {
        const stream = await navigator.mediaDevices.getUserMedia({
          video: {
            facingMode: "environment",
            width: { exact: 390 },
            height: { exact: 300 }
          }
        });
        videoStream.value = stream;
        video.value.srcObject = stream;
        video.value.onloadedmetadata = () => {
          const barcodeDetector = new BarcodeDetector();
          const scanBarcode = async () => {
            if (!scanning.value) {
              return;
            }
            try {
              const barCodes = await barcodeDetector.detect(video.value);
              if (barCodes.length > 0) {
                handleDetected(barCodes);
              }
            } catch (err) {
              console.error("Scan barcode error", err);
            }
            requestAnimationFrame(scanBarcode);
          };
          scanBarcode();
        };
      } catch (error) {
        console.error("Cannot access camera", error);
      }
    };
    const stopScan = () => {
      resultSets.value = {};
      scanning.value = false;
      if (videoStream.value) {
        const tracks = videoStream.value.getTracks();
        tracks.forEach((track) => track.stop());
      }
      if (video.value) {
        video.value.srcObject = null;
      }
    };
    onBeforeUnmount(() => {
      stopScan();
    });
    onMounted(() => {
      initBarcodeScanner();
    });
    __expose({
      video,
      scanning,
      setScanning
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1, [
        createBaseVNode("div", _hoisted_2, [
          renderSlot(_ctx.$slots, "header", {}, void 0, true)
        ]),
        createBaseVNode("video", {
          ref_key: "video",
          ref: video,
          playsinline: "",
          autoplay: ""
        }, null, 512),
        _hoisted_3
      ]);
    };
  }
});
const BarcodeScannerVideo_vue_vue_type_style_index_0_scoped_05fd75fc_lang = "";
const BarcodeScannerVideo = /* @__PURE__ */ _export_sfc(_sfc_main$1, [["__scopeId", "data-v-05fd75fc"]]);
const _hoisted_1 = {
  key: 0,
  class: "tw-p-4 tw-text-white tw-text-center"
};
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "ScanProductModal",
  setup(__props) {
    const languageStore = useLanguageStore();
    const commonModalsStore = useCommonModalsStore();
    const { __ } = languageStore;
    const productSearchStore = useProductSearch();
    const code = ref("");
    const scanner = ref();
    const exitModal = () => {
      commonModalsStore.hideScanProductModal();
      productSearchStore.mode = "search";
    };
    const handleCancelModel = () => {
      exitModal();
    };
    const handleNoSupport = () => {
    };
    const handleDetected = (rawCode) => {
      if (productSearchStore.fetching) {
        return;
      }
      code.value = rawCode;
      productSearchStore.keyword = code.value;
      productSearchStore.mode = "scan";
      productSearchStore.scanProduct(rawCode).finally(() => {
        code.value = "";
        exitModal();
      });
    };
    const pauseOrPlayVideoBaseOnFetching = () => {
      if (productSearchStore.fetching) {
        scanner.value.video.pause();
      } else {
        scanner.value.video.play();
      }
    };
    watch(
      () => productSearchStore.fetching,
      () => pauseOrPlayVideoBaseOnFetching()
    );
    const handleStop = () => {
    };
    return (_ctx, _cache) => {
      const _component_a_modal = resolveComponent("a-modal");
      return openBlock(), createBlock(_component_a_modal, {
        visible: unref(commonModalsStore).scanProductModal.visible,
        title: unref(__)("Scan product"),
        class: "modal-scan-product modal-no-footer",
        onCancel: handleCancelModel
      }, {
        footer: withCtx(() => []),
        default: withCtx(() => [
          createVNode(BarcodeScannerVideo, {
            ref_key: "scanner",
            ref: scanner,
            onNoSupport: handleNoSupport,
            onDetected: handleDetected,
            onStop: handleStop
          }, {
            header: withCtx(() => [
              code.value ? (openBlock(), createElementBlock("div", _hoisted_1, [
                createBaseVNode("span", null, [
                  createTextVNode(toDisplayString(unref(__)("Searching")) + ": ", 1),
                  createBaseVNode("code", null, toDisplayString(code.value), 1)
                ])
              ])) : createCommentVNode("", true)
            ]),
            _: 1
          }, 512)
        ]),
        _: 1
      }, 8, ["visible", "title"]);
    };
  }
});
const ScanProductModal_vue_vue_type_style_index_0_lang = "";
export {
  _sfc_main as default
};
