import { d as defineComponent, f as useLanguageStore, k as usePosStore, K as ref, L as onMounted, r as resolveComponent, o as openBlock, a as createBlock, O as withCtx, i as createBaseVNode, p as createVNode, n as normalizeClass, t as toDisplayString, h as currencyFormat, T as Modal } from "./index.uaDs3xEUfw.js";
import { u as useReportApi, d as downloadCsvFile } from "./csv.uaDs3xEUfw.js";
import { a as humanFormat } from "./datetime.uaDs3xEUfw.js";
const _hoisted_1 = { class: "tw-ml-auto tw-font-semibold" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "TodayProfitReport",
  setup(__props, { expose: __expose }) {
    const languageStore = useLanguageStore();
    const { __ } = languageStore;
    const posStore = usePosStore();
    const isLoading = ref(false);
    const reportLines = ref([]);
    onMounted(() => {
      const f = async () => {
        var _a;
        const reportApi = await useReportApi();
        isLoading.value = true;
        try {
          const { data } = await reportApi.currentSession(posStore.register.id);
          const reportInformation = {
            openTime: {
              label: __("Open time"),
              type: "datetime",
              valueFormat: (value) => humanFormat(value)
            },
            cashiers: {
              label: __("Cashiers"),
              type: "array",
              valueFormat: (value) => value.map(
                (item) => item.full_name != void 0 ? item.full_name : item.username
              ).join(", ")
            },
            numItemsSold: {
              label: __("Products"),
              type: "number",
              valueFormat: (value) => value
            },
            ordersCount: {
              label: __("Orders"),
              type: "number",
              valueFormat: (value) => value
            },
            cashInHand: {
              label: __("Cash in hand"),
              type: "price",
              valueFormat: (value) => currencyFormat(value)
            },
            netTotal: {
              label: __("Net total"),
              type: "price",
              valueFormat: (value) => currencyFormat(value)
            },
            totalSales: {
              label: __("Total sales"),
              type: "price",
              valueFormat: (value) => currencyFormat(value),
              classes: ["tw-text-primary"]
            },
            cashTotal: {
              label: __("Cash total"),
              type: "price",
              valueFormat: (value) => currencyFormat(value),
              classes: ["tw-text-primary"]
            }
          };
          for (const reportName in reportInformation) {
            const reportInfo = reportInformation[reportName];
            const value = data[reportName];
            reportLines.value.push({
              title: __(reportInfo.label),
              formattedValue: value != void 0 ? reportInfo.valueFormat(value) : null,
              originValue: value,
              type: reportInfo.type,
              classes: reportInfo.classes || []
            });
          }
        } catch (error) {
          console.error(error);
          Modal.error({
            title: __("Load report data unsuccessfully"),
            content: JSON.stringify((_a = error == null ? void 0 : error.posifyError) == null ? void 0 : _a.details)
          });
        }
        isLoading.value = false;
      };
      f();
    });
    const exportReportToCsv = () => {
      const csvRows = reportLines.value.map((report) => {
        let value = report.originValue;
        if (report.type === "array") {
          value = report.formattedValue;
        }
        return {
          entry: report.title,
          value
        };
      });
      downloadCsvFile(csvRows, {
        filename: `session_${posStore.registerSession.id}_report`,
        headers: [__("Entry"), __("Value")]
      });
    };
    __expose({
      isLoading,
      exportReportToCsv
    });
    return (_ctx, _cache) => {
      const _component_a_list_item = resolveComponent("a-list-item");
      const _component_a_list = resolveComponent("a-list");
      const _component_a_spin = resolveComponent("a-spin");
      return openBlock(), createBlock(_component_a_spin, { spinning: isLoading.value }, {
        default: withCtx(() => [
          createBaseVNode("div", null, [
            createVNode(_component_a_list, { "data-source": reportLines.value }, {
              renderItem: withCtx(({ item }) => [
                createVNode(_component_a_list_item, {
                  class: normalizeClass(item.classes)
                }, {
                  default: withCtx(() => [
                    createBaseVNode("div", null, toDisplayString(item.title), 1),
                    createBaseVNode("div", _hoisted_1, toDisplayString(item.formattedValue), 1)
                  ]),
                  _: 2
                }, 1032, ["class"])
              ]),
              _: 1
            }, 8, ["data-source"])
          ])
        ]),
        _: 1
      }, 8, ["spinning"]);
    };
  }
});
export {
  _sfc_main as _
};
