import { t as toWooParams } from "./params.uaDs3xEUfw.js";
const toCoupon = (coupon) => {
  const discountTypes = {
    percent: "percentage"
  };
  return {
    id: coupon.id,
    code: coupon.code,
    amount: Number(coupon.amount),
    amountType: discountTypes[coupon.discount_type] || coupon.discount_type,
    expiryDate: coupon.date_expires,
    createdAt: coupon.date_created,
    updatedAt: coupon.date_modified,
    usageLimit: coupon.usage_limit,
    usageLimitPerUser: coupon.usage_limit_per_user,
    limitUsageToXItems: coupon.limit_usage_to_x_items,
    freeShipping: coupon.free_shipping,
    productIds: coupon.product_ids,
    excludedProductIds: coupon.excluded_product_ids,
    productCategories: coupon.product_categories,
    excludedProductCategories: coupon.excluded_product_categories,
    excludeSaleItems: coupon.exclude_sale_items,
    minimumAmount: Number(coupon.minimum_amount),
    maximumAmount: Number(coupon.maximum_amount),
    emailRestrictions: coupon.email_restrictions,
    usageCount: Number(coupon.usage_count),
    individualUse: coupon.individual_use
  };
};
const toWooCoupon = (coupon) => {
  const discountTypes = {
    percentage: "percent"
  };
  return {
    discount_type: discountTypes[coupon.amountType] || coupon.amountType,
    code: coupon.code,
    amount: coupon.amount,
    productIds: coupon.productIds,
    excluded_product_ids: coupon.excludedProductIds,
    usage_limit: coupon.usageLimit,
    usage_limit_per_user: coupon.usageLimitPerUser,
    limit_usage_to_x_items: coupon.limitUsageToXItems,
    free_shipping: coupon.freeShipping,
    product_categories: coupon.productCategories,
    excluded_product_categories: coupon.excludedProductCategories,
    exclude_sale_items: coupon.excludeSaleItems,
    minimum_amount: coupon.minimumAmount,
    maximum_amount: coupon.maximumAmount,
    email_restrictions: coupon.emailRestrictions,
    date_created: coupon.createdAt,
    date_modified: coupon.updatedAt,
    date_expires: coupon.expiryDate,
    usage_count: coupon.usageCount,
    individual_use: coupon.individualUse
  };
};
const getList = (httpClient, params) => {
  return httpClient.get("wc/v3/coupons", { params: toWooParams(params) }).then((response) => {
    response.data = response.data.map(toCoupon);
    return response;
  });
};
const create = (httpClient, data) => {
  return httpClient.post("coupons", data).then((response) => {
    return response;
  });
};
const batchUpdate = (httpClient, data) => {
  const wooData = {};
  if (data.create) {
    wooData.create = data.create.map(toWooCoupon);
  }
  return httpClient.post("wc/v3/coupons/batch", wooData).then((response) => {
    return response;
  });
};
const couponApiFactory = (httpClient) => ({
  create: (data) => create(httpClient, data),
  batchUpdate: (data) => batchUpdate(httpClient, data),
  getList: (params) => getList(httpClient, params)
});
export {
  couponApiFactory as default
};
