import { a4 as requestFactory } from "./index.uaDs3xEUfw.js";
const useReportApi = async () => requestFactory("report");
var build = {};
var exportToCsv = {};
(function(exports) {
  Object.defineProperty(exports, "__esModule", { value: true });
  var CsvConfigConsts = function() {
    function CsvConfigConsts2() {
    }
    CsvConfigConsts2.EOL = "\r\n";
    CsvConfigConsts2.BOM = "\uFEFF";
    CsvConfigConsts2.DEFAULT_FIELD_SEPARATOR = ",";
    CsvConfigConsts2.DEFAULT_DECIMAL_SEPARATOR = ".";
    CsvConfigConsts2.DEFAULT_QUOTE = '"';
    CsvConfigConsts2.DEFAULT_SHOW_TITLE = false;
    CsvConfigConsts2.DEFAULT_TITLE = "My Generated Report";
    CsvConfigConsts2.DEFAULT_FILENAME = "generated";
    CsvConfigConsts2.DEFAULT_SHOW_LABELS = false;
    CsvConfigConsts2.DEFAULT_USE_TEXT_FILE = false;
    CsvConfigConsts2.DEFAULT_USE_BOM = true;
    CsvConfigConsts2.DEFAULT_HEADER = [];
    CsvConfigConsts2.DEFAULT_KEYS_AS_HEADERS = false;
    return CsvConfigConsts2;
  }();
  exports.CsvConfigConsts = CsvConfigConsts;
  exports.ConfigDefaults = {
    filename: CsvConfigConsts.DEFAULT_FILENAME,
    fieldSeparator: CsvConfigConsts.DEFAULT_FIELD_SEPARATOR,
    quoteStrings: CsvConfigConsts.DEFAULT_QUOTE,
    decimalSeparator: CsvConfigConsts.DEFAULT_DECIMAL_SEPARATOR,
    showLabels: CsvConfigConsts.DEFAULT_SHOW_LABELS,
    showTitle: CsvConfigConsts.DEFAULT_SHOW_TITLE,
    title: CsvConfigConsts.DEFAULT_TITLE,
    useTextFile: CsvConfigConsts.DEFAULT_USE_TEXT_FILE,
    useBom: CsvConfigConsts.DEFAULT_USE_BOM,
    headers: CsvConfigConsts.DEFAULT_HEADER,
    useKeysAsHeaders: CsvConfigConsts.DEFAULT_KEYS_AS_HEADERS
  };
  var ExportToCsv = function() {
    function ExportToCsv2(options) {
      this._csv = "";
      var config = options || {};
      this._options = objectAssign({}, exports.ConfigDefaults, config);
      if (this._options.useKeysAsHeaders && this._options.headers && this._options.headers.length > 0) {
        console.warn("Option to use object keys as headers was set, but headers were still passed!");
      }
    }
    Object.defineProperty(ExportToCsv2.prototype, "options", {
      get: function() {
        return this._options;
      },
      set: function(options) {
        this._options = objectAssign({}, exports.ConfigDefaults, options);
      },
      enumerable: true,
      configurable: true
    });
    ExportToCsv2.prototype.generateCsv = function(jsonData, shouldReturnCsv) {
      if (shouldReturnCsv === void 0) {
        shouldReturnCsv = false;
      }
      this._csv = "";
      this._parseData(jsonData);
      if (this._options.useBom) {
        this._csv += CsvConfigConsts.BOM;
      }
      if (this._options.showTitle) {
        this._csv += this._options.title + "\r\n\n";
      }
      this._getHeaders();
      this._getBody();
      if (this._csv == "") {
        console.log("Invalid data");
        return;
      }
      if (shouldReturnCsv) {
        return this._csv;
      }
      var FileType = this._options.useTextFile ? "plain" : "csv";
      var fileExtension = this._options.useTextFile ? ".txt" : ".csv";
      var blob = new Blob([this._csv], { "type": "text/" + FileType + ";charset=utf8;" });
      if (navigator.msSaveBlob) {
        var filename = this._options.filename.replace(/ /g, "_") + fileExtension;
        navigator.msSaveBlob(blob, filename);
      } else {
        var attachmentType = this._options.useTextFile ? "text" : "csv";
        "data:attachment/" + attachmentType + ";charset=utf-8," + encodeURI(this._csv);
        var link = document.createElement("a");
        link.href = URL.createObjectURL(blob);
        link.setAttribute("visibility", "hidden");
        link.download = this._options.filename.replace(/ /g, "_") + fileExtension;
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
      }
    };
    ExportToCsv2.prototype._getHeaders = function() {
      if (!this._options.showLabels && !this._options.useKeysAsHeaders) {
        return;
      }
      var useKeysAsHeaders = this._options.useKeysAsHeaders;
      var headers = useKeysAsHeaders ? Object.keys(this._data[0]) : this._options.headers;
      if (headers.length > 0) {
        var row = "";
        for (var keyPos = 0; keyPos < headers.length; keyPos++) {
          row += headers[keyPos] + this._options.fieldSeparator;
        }
        row = row.slice(0, -1);
        this._csv += row + CsvConfigConsts.EOL;
      }
    };
    ExportToCsv2.prototype._getBody = function() {
      var keys = Object.keys(this._data[0]);
      for (var i = 0; i < this._data.length; i++) {
        var row = "";
        for (var keyPos = 0; keyPos < keys.length; keyPos++) {
          var key = keys[keyPos];
          row += this._formatData(this._data[i][key]) + this._options.fieldSeparator;
        }
        row = row.slice(0, -1);
        this._csv += row + CsvConfigConsts.EOL;
      }
    };
    ExportToCsv2.prototype._formatData = function(data) {
      if (this._options.decimalSeparator === "locale" && this._isFloat(data)) {
        return data.toLocaleString();
      }
      if (this._options.decimalSeparator !== "." && this._isFloat(data)) {
        return data.toString().replace(".", this._options.decimalSeparator);
      }
      if (typeof data === "string") {
        data = data.replace(/"/g, '""');
        if (this._options.quoteStrings || data.indexOf(",") > -1 || data.indexOf("\n") > -1 || data.indexOf("\r") > -1) {
          data = this._options.quoteStrings + data + this._options.quoteStrings;
        }
        return data;
      }
      if (typeof data === "boolean") {
        return data ? "TRUE" : "FALSE";
      }
      return data;
    };
    ExportToCsv2.prototype._isFloat = function(input) {
      return +input === input && (!isFinite(input) || Boolean(input % 1));
    };
    ExportToCsv2.prototype._parseData = function(jsonData) {
      this._data = typeof jsonData != "object" ? JSON.parse(jsonData) : jsonData;
      return this._data;
    };
    return ExportToCsv2;
  }();
  exports.ExportToCsv = ExportToCsv;
  var hasOwnProperty = Object.prototype.hasOwnProperty;
  var propIsEnumerable = Object.prototype.propertyIsEnumerable;
  function toObject(val) {
    if (val === null || val === void 0) {
      throw new TypeError("Object.assign cannot be called with null or undefined");
    }
    return Object(val);
  }
  function objectAssign(target) {
    var from;
    var to = toObject(target);
    var symbols;
    for (var s = 1; s < arguments.length; s++) {
      from = Object(arguments[s]);
      for (var key in from) {
        if (hasOwnProperty.call(from, key)) {
          to[key] = from[key];
        }
      }
      if (Object.getOwnPropertySymbols) {
        symbols = Object.getOwnPropertySymbols(from);
        for (var i = 0; i < symbols.length; i++) {
          if (propIsEnumerable.call(from, symbols[i])) {
            to[symbols[i]] = from[symbols[i]];
          }
        }
      }
    }
    return to;
  }
})(exportToCsv);
(function(exports) {
  function __export(m) {
    for (var p in m)
      if (!exports.hasOwnProperty(p))
        exports[p] = m[p];
  }
  Object.defineProperty(exports, "__esModule", { value: true });
  __export(exportToCsv);
})(build);
const downloadCsvFile = (data, options) => {
  options = Object.assign(
    {
      fieldSeparator: ",",
      quoteStrings: '"',
      decimalSeparator: ".",
      showLabels: true,
      showTitle: false,
      useBom: true
    },
    options || {}
  );
  const csvExporter = new build.ExportToCsv(options);
  csvExporter.generateCsv(data);
};
export {
  downloadCsvFile as d,
  useReportApi as u
};
