import { ak as defineStore, l as useCartItemStore, m as useCommonModalsStore, f as useLanguageStore, a5 as useGeneralSettingStore, k as usePosStore, aW as useProductStore, s as storeToRefs, K as ref, g as computed, V as message, aX as arrFirst } from "./index.uaDs3xEUfw.js";
const useProductSearch = defineStore(
  "useProductSearch",
  () => {
    const cartItemStore = useCartItemStore();
    const commonModalsStore = useCommonModalsStore();
    const languageStore = useLanguageStore();
    const generalSettingStore = useGeneralSettingStore();
    const posStore = usePosStore();
    const productStore = useProductStore();
    const { persistenceDataFetching } = storeToRefs(productStore);
    const keyword = ref("");
    const mode = ref("search");
    const products = ref([]);
    const _fetching = ref(false);
    const fetching = computed(
      () => persistenceDataFetching.value || _fetching.value
    );
    const { __ } = languageStore;
    const fetchProducts = async (keyword2) => {
      products.value = [];
      _fetching.value = true;
      const productRepository = productStore.repository;
      const params = {
        search: keyword2,
        perPage: 5,
        storeId: posStore.store.id
      };
      return productRepository.getList(params).then(({ data }) => {
        products.value = data;
      }).finally(() => {
        _fetching.value = false;
      });
    };
    const scanProduct = async (keyword2) => {
      products.value = [];
      _fetching.value = true;
      const productRepository = productStore.repository;
      const productScanField = generalSettingStore.productScanField;
      const params = {
        [productScanField]: keyword2,
        perPage: 1,
        storeId: posStore.store.id
      };
      return productRepository.getList(params).then(({ data }) => {
        if (data.length != 1) {
          message.error(__("Product not found"));
          return;
        }
        const productInfo = arrFirst(data);
        if (productInfo.type == "variable") {
          const variationInfo = productInfo.variations.find(
            (i) => i[productScanField] == keyword2
          );
          if (!variationInfo) {
            commonModalsStore.showVariationModal({
              productId: productInfo.id,
              productTitle: productInfo.title
            });
            return;
          }
          if (!variationInfo.purchasable) {
            message.error(__("Product is not purchasable"));
            return;
          }
          cartItemStore.add({
            productId: productInfo.id,
            productTitle: productInfo.title,
            variationId: variationInfo.id,
            price: variationInfo.price,
            regularPrice: variationInfo.regularPrice,
            thumbnail: variationInfo.thumbnail,
            options: variationInfo.options,
            manageStock: variationInfo.manageStock,
            stockQuantity: variationInfo.stockQuantity,
            taxClass: variationInfo.taxClass,
            taxStatus: variationInfo.taxStatus
          });
          return;
        }
        if (!productInfo.purchasable) {
          message.error(__("Product is not purchasable"));
          return;
        }
        cartItemStore.add({
          productId: productInfo.id,
          productTitle: productInfo.title,
          variationId: void 0,
          thumbnail: productInfo.thumbnail,
          options: void 0,
          price: productInfo.price,
          regularPrice: productInfo.regularPrice,
          manageStock: productInfo.manageStock,
          stockQuantity: productInfo.stockQuantity,
          taxClass: productInfo.taxClass,
          taxStatus: productInfo.taxStatus
        });
      }).finally(() => {
        _fetching.value = false;
      });
    };
    const addProduct = (productId) => {
      const productInfo = products.value.find(
        (product) => product.id == productId
      );
      if (productInfo.variations.length > 0) {
        commonModalsStore.showVariationModal({
          productId: productInfo.id,
          productTitle: productInfo.title
        });
        return;
      }
      if (!productInfo.purchasable) {
        message.error(__("Product is not purchasable"));
        return;
      }
      cartItemStore.add({
        productId,
        productTitle: productInfo.title,
        variationId: void 0,
        thumbnail: productInfo.thumbnail,
        options: void 0,
        price: productInfo.price,
        regularPrice: productInfo.regularPrice,
        manageStock: productInfo.manageStock,
        stockQuantity: productInfo.stockQuantity,
        taxClass: productInfo.taxClass,
        taxStatus: productInfo.taxStatus
      });
    };
    return {
      keyword,
      mode,
      products,
      fetching,
      fetchProducts,
      scanProduct,
      addProduct
    };
  },
  {
    // persist: true,
  }
);
export {
  useProductSearch as u
};
