<?php

namespace Posify\Core\DataTransferObjects;

use Posify\Core\DataTransferObjects\Factories\CreateRegisterDataFactory;
use Posify\Core\Exceptions\DataInvalidException;
use Posify\Core\Utilities\HasFactory;
use Posify\Core\Utilities\HasMakeFactory;
use Posify\Core\Utilities\HasTransformObject;
use Posify\Core\Validation\Validator;

class CreateRegisterData
{
    use HasMakeFactory;
    use HasFactory;
    use HasTransformObject;

    public $name = null;
    public $store_id = null;
    public $receipt_id = null;
    public $payment_gateways = [];
    public $closing_report_enabled = true;
    public $closing_report_note_enabled = true;
    public $enabled = false;
    public $catalog_include_type = 'all';
    public $catalog_include_categories = [];
    public $catalog_include_products = [];
    public $catalog_show_in_pos_type = 'categories';
    public $numeric_controller_discount_presets = [5, 10, 15, 20, 25];
    public $fee_and_discount_presets = [5, 10, 15, 20, 25];
    public $shipping_methods = [];
    public $tax_classes = [];
    public $tax_status = [];
    public $audio_enabled = true;
    public $scan_enabled = true;
    public $guest_checkout_enabled = true;
    public $create_product_enabled = true;
    public $shipping_enabled = true;
    public $default_payment_gateway = null;
    public $default_shipping_method = null;
    public $default_tax_class = null;
    public $default_tax_status = null;
    public $auto_print_receipt_enabled = true;
    public $show_stock_quantity = true;

    public function __construct(
        $name = null,
        $store_id = null,
        $receipt_id = null,
        $payment_gateways = [],
        $closing_report_enabled = true,
        $closing_report_note_enabled = true,
        $enabled = false,
        $catalog_include_type = 'all',
        $catalog_include_categories = [],
        $catalog_include_products = [],
        $catalog_show_in_pos_type = 'categories',
        $numeric_controller_discount_presets = [5, 10, 15, 20, 25],
        $fee_and_discount_presets = [5, 10, 15, 20, 25],
        $shipping_methods = [],
        $tax_classes = [],
        $tax_status = [],
        $audio_enabled = true,
        $scan_enabled = true,
        $guest_checkout_enabled = true,
        $create_product_enabled = true,
        $shipping_enabled = true,
        $default_payment_gateway = null,
        $default_shipping_method = null,
        $default_tax_class = null,
        $default_tax_status = null,
        $auto_print_receipt_enabled = true,
        $show_stock_quantity = true
    ) {
        $this->name = $name;
        $this->store_id = $store_id;
        $this->receipt_id = $receipt_id;
        $this->payment_gateways = $payment_gateways;
        $this->closing_report_enabled = $closing_report_enabled;
        $this->closing_report_note_enabled = $closing_report_note_enabled;
        $this->enabled = $enabled;
        $this->catalog_include_type = $catalog_include_type;
        $this->catalog_include_categories = $catalog_include_categories;
        $this->catalog_include_products = $catalog_include_products;
        $this->catalog_show_in_pos_type = $catalog_show_in_pos_type;
        $this->numeric_controller_discount_presets = $numeric_controller_discount_presets;
        $this->fee_and_discount_presets = $fee_and_discount_presets;
        $this->shipping_methods = $shipping_methods;
        $this->tax_classes = $tax_classes;
        $this->tax_status = $tax_status;
        $this->audio_enabled = $audio_enabled;
        $this->scan_enabled = $scan_enabled;
        $this->guest_checkout_enabled = $guest_checkout_enabled;
        $this->create_product_enabled = $create_product_enabled;
        $this->shipping_enabled = $shipping_enabled;
        $this->default_payment_gateway = $default_payment_gateway;
        $this->default_shipping_method = $default_shipping_method;
        $this->default_tax_class = $default_tax_class;
        $this->default_tax_status = $default_tax_status;
        $this->auto_print_receipt_enabled = $auto_print_receipt_enabled;
        $this->show_stock_quantity = $show_stock_quantity;
    }

    public static function factoryClass()
    {
        return CreateRegisterDataFactory::class;
    }

    public function validate()
    {
        $validator = Validator::make($this->toArray(), [
            // 'name' => ['max:255'],
            // 'store_id' => ['required', 'integer', new StoreMustExists],
            // 'receipt_id' => ['required', 'integer'],
        ]);

        if ($validator->fails()) {
            throw DataInvalidException::fromValidator($validator);
        }
    }
}
