<?php

namespace Posify\Core\UseCases;

use Posify\Core\DataTransferObjects\AddRegisterCashData;
use Posify\Core\Entities\RegisterCash;
use Posify\Core\Entities\RegisterSession;
use Posify\Core\Exceptions\DataInvalidException;
use Posify\Core\Loader;

class AddRegisterCash
{
    public RegisterSession $registerSession;
    public AddRegisterCashData $data;

    public function __construct(
        RegisterSession $registerSession,
        AddRegisterCashData $data
    ) {
        $this->registerSession = $registerSession;
        $this->data = $data;
    }

    public function handle(): RegisterCash
    {
        if ($this->registerSession->isOpen() == false) {
            throw new DataInvalidException('register_session_already_closed', 'register_session_already_closed');
        }

        $registerCash = Loader::load(RegisterCash::class);

        $registerCash->setStoreId($this->registerSession->getStoreId());
        $registerCash->setRegisterId($this->registerSession->getRegisterId());
        $registerCash->setEmployeeId($this->registerSession->getEmployeeId());
        $registerCash->setSessionId($this->registerSession->getId());
        $registerCash->setAmount($this->data->amount ?? 0);
        $registerCash->setDescription($this->data->description);
        $registerCash->save();

        return $registerCash;
    }

    public static function make(
        RegisterSession $registerSession,
        AddRegisterCashData $data
    ) {
        return new static(
            $registerSession,
            $data,
        );
    }
}
