<?php

namespace Posify\Core\UseCases;

use Posify\Core\DataTransferObjects\CreateReceiptData;
use Posify\Core\Entities\Receipt;
use Posify\Core\Loader;

class CreateReceipt
{
    public CreateReceiptData $data;

    public function __construct(
        CreateReceiptData $data
    ) {
        $this->data = $data;
    }

    public function handle(): Receipt
    {
        $this->data->validate();

        $receipt = Loader::load(Receipt::class);

        $receipt->setName($this->data->name);
        $receipt->setShowLogo($this->data->show_logo);
        $receipt->setLogoUrl($this->data->logo_url);
        $receipt->setShowSku($this->data->show_sku);
        $receipt->setSkuLabel($this->data->sku_label ?? esc_html__('SKU', 'posify-for-woocommerce'));
        $receipt->setShowStoreName($this->data->show_store_name);
        $receipt->setReceiptFooter($this->data->receipt_footer);
        $receipt->setShowVat($this->data->show_vat);
        $receipt->setVatLabel($this->data->vat_label ?? esc_html__('VAT', 'posify-for-woocommerce'));
        $receipt->setShowAddress($this->data->show_address);
        $receipt->setShowPhone($this->data->show_phone);
        $receipt->setShowEmail($this->data->show_email);
        $receipt->setShowFax($this->data->show_fax);
        $receipt->setShowWebsite($this->data->show_website);
        $receipt->setShowFacebook($this->data->show_facebook);
        $receipt->setShowTwitter($this->data->show_twitter);
        $receipt->setShowInstagram($this->data->show_instagram);
        $receipt->setShowYoutube($this->data->show_youtube);
        $receipt->setShowOrderDate($this->data->show_order_date);
        $receipt->setOrderDateLabel($this->data->order_date_label ?? esc_html__('Order date', 'posify-for-woocommerce'));
        $receipt->setShowOrderNumber($this->data->show_order_number);
        $receipt->setOrderNumberLabel($this->data->order_number_label ?? esc_html__('Order number', 'posify-for-woocommerce'));
        $receipt->setShowOrderCustomer($this->data->show_order_customer);
        $receipt->setOrderCustomerLabel($this->data->order_customer_label ?? esc_html__('Customer', 'posify-for-woocommerce'));
        $receipt->setShowShipping($this->data->show_shipping);
        $receipt->setShippingLabel($this->data->shipping_label ?? esc_html__('Shipping', 'posify-for-woocommerce'));
        $receipt->setShowOrderRegister($this->data->show_order_register);
        $receipt->setOrderRegisterLabel($this->data->order_register_label ?? esc_html__('Register', 'posify-for-woocommerce'));
        $receipt->setShowCashier($this->data->show_cashier);
        $receipt->setCashierLabel($this->data->cashier_label ?? esc_html__('Cashier', 'posify-for-woocommerce'));
        $receipt->setShowCustomerNote($this->data->show_customer_note);
        $receipt->setCustomerNoteLabel($this->data->customer_note_label ?? esc_html__('Note', 'posify-for-woocommerce'));
        $receipt->save();

        return $receipt;
    }

    public static function make(
        CreateReceiptData $data
    ) {
        return new static(
            $data,
        );
    }
}
