<?php

namespace Posify\Core\UseCases;

use Posify\Core\DataTransferObjects\CreateRegisterData;
use Posify\Core\Entities\Register;
use Posify\Core\Loader;

class CreateRegister
{
    public CreateRegisterData $data;

    public function __construct(
        CreateRegisterData $data
    ) {
        $this->data = $data;
    }

    public function handle(): Register
    {
        $this->data->validate();

        $register = Loader::load(Register::class);

        $register->setName($this->data->name);
        $register->setStoreId($this->data->store_id);
        $register->setReceiptId($this->data->receipt_id);
        $register->setPaymentGateways($this->data->payment_gateways);
        $register->setClosingReportEnabled($this->data->closing_report_enabled);
        $register->setClosingReportNoteEnabled($this->data->closing_report_note_enabled);
        $register->setEnabled($this->data->enabled);
        $register->setCatalogIncludeType($this->data->catalog_include_type);
        $register->setCatalogIncludeCategories($this->data->catalog_include_categories);
        $register->setCatalogIncludeProducts($this->data->catalog_include_products);
        $register->setCatalogShowInPosType($this->data->catalog_show_in_pos_type);
        $register->setNumericControllerDiscountPresets($this->data->numeric_controller_discount_presets);
        $register->setFeeAndDiscountPresets($this->data->fee_and_discount_presets);
        $register->setShippingMethods($this->data->shipping_methods);
        $register->setTaxClasses($this->data->tax_classes);
        $register->setTaxStatus($this->data->tax_status);
        $register->setAudioEnabled($this->data->audio_enabled);
        $register->setScanEnabled($this->data->scan_enabled);
        $register->setGuestCheckoutEnabled($this->data->guest_checkout_enabled);
        $register->setCreateProductEnabled($this->data->create_product_enabled);
        $register->setShippingEnabled($this->data->shipping_enabled);
        $register->setDefaultPaymentGateway($this->data->default_payment_gateway);
        $register->setDefaultShippingMethod($this->data->default_shipping_method);
        $register->setDefaultTaxClass($this->data->default_tax_class);
        $register->setDefaultTaxStatus($this->data->default_tax_status);
        $register->setAutoPrintReceiptEnabled($this->data->auto_print_receipt_enabled);
        $register->setShowStockQuantity($this->data->show_stock_quantity);
        $register->save();

        return $register;
    }

    public static function make(
        CreateRegisterData $data
    ) {
        return new static(
            $data,
        );
    }
}
