<?php

namespace Posify\Core\UseCases;

use Posify\Core\Entities\Receipt;
use Posify\Core\Exceptions\DataInvalidException;

class DeleteReceipt
{
    protected $receiptRepository;

    public Receipt $receipt;

    public function __construct(
        Receipt $receipt
    ) {
        $this->receipt = $receipt;
    }

    public function handle(): void
    {
        if ($this->receipt->isUsedInRegisters()) {
            throw new DataInvalidException(
                'receipt_is_used_in_registers',
               esc_html__('This receipt is used in some registers, so we cannot delete it', 'posify-for-woocommerce')
            );
        }

        $this->receipt->delete();
    }

    public static function make(
        Receipt $receipt
    ) {
        return new static(
            $receipt,
        );
    }
}
