<?php

namespace Posify\Core\UseCases;

use Posify\Core\Entities\Employee;
use Posify\Core\Entities\Register;
use Posify\Core\Entities\RegisterSession;
use Posify\Core\Loader;

class OpenRegisterSession
{
    public Register $register;
    public Employee $employee;
    public string $openTime;

    public function __construct(
        Register $register,
        Employee $employee,
        string $openTime
    ) {
        $this->register = $register;
        $this->employee = $employee;
        $this->openTime = $openTime;
    }

    public function handle(): RegisterSession
    {
        $registerSession = Loader::load(RegisterSession::class);
        $registerSession->setRegisterId($this->register->getId());
        $registerSession->setStoreId($this->register->getStoreId());
        $registerSession->setEmployeeId($this->employee->getId());
        $registerSession->setOpenTime($this->openTime);
        $registerSession->save();

        $registerSession->employeeActions()->create([
            'employee_id' => $this->employee->getId(),
            'action' => 'open_session',
        ]);

        return $registerSession;
    }

    public static function make(
        Register $register,
        Employee $employee,
        string $openTime
    ) {
        return new static(
            $register,
            $employee,
            $openTime
        );
    }
}
