<?php

namespace Posify\Core\UseCases;

use Posify\Core\Entities\Employee;
use Posify\Core\Entities\RegisterSession;

class TakeOverRegisterSession
{
    public RegisterSession $registerSession;
    public Employee $employee;

    public function __construct(
        RegisterSession $registerSession,
        Employee $employee
    ) {
        $this->registerSession = $registerSession;
        $this->employee = $employee;
    }

    public function handle(): void
    {
        $beforeEmployeeId = $this->registerSession->getEmployeeId();

        $this->registerSession->setEmployeeId($this->employee->getId());
        $this->registerSession->save();

        $this->registerSession->employeeActions()->create([
            'employee_id' => $this->employee->getId(),
            'action' => 'take_over_session',
            'meta' => [
                [
                    'key' => 'before_employee_id',
                    'value' => $beforeEmployeeId,
                ]
            ],
        ]);
    }

    public static function make(
        RegisterSession $registerSession,
        Employee $employee
    ) {
        return new static(
            $registerSession,
            $employee,
        );
    }
}
