<?php

namespace Posify\Core\UseCases;

use Posify\Core\DataTransferObjects\UpdateReceiptData;
use Posify\Core\Entities\Receipt;
use Posify\Core\ValueObjects\Undefined;

class UpdateReceipt
{
    public Receipt $receipt;
    public UpdateReceiptData $data;

    public function __construct(
        Receipt $receipt,
        UpdateReceiptData $data
    ) {
        $this->receipt = $receipt;
        $this->data = $data;
    }

    public function handle(): Receipt
    {
        if (!Undefined::is($this->data->name)) {
            $this->receipt->setName($this->data->name);
        }

        if (!Undefined::is($this->data->show_logo)) {
            $this->receipt->setShowLogo($this->data->show_logo);
        }

        if (!Undefined::is($this->data->logo_url)) {
            $this->receipt->setLogoUrl($this->data->logo_url);
        }

        if (!Undefined::is($this->data->show_sku)) {
            $this->receipt->setShowSku($this->data->show_sku);
        }

        if (!Undefined::is($this->data->sku_label)) {
            $this->receipt->setSkuLabel($this->data->sku_label);
        }

        if (!Undefined::is($this->data->show_store_name)) {
            $this->receipt->setShowStoreName($this->data->show_store_name);
        }

        if (!Undefined::is($this->data->receipt_footer)) {
            $this->receipt->setReceiptFooter($this->data->receipt_footer);
        }

        if (!Undefined::is($this->data->show_vat)) {
            $this->receipt->setShowVat($this->data->show_vat);
        }

        if (!Undefined::is($this->data->vat_label)) {
            $this->receipt->setVatLabel($this->data->vat_label);
        }

        if (!Undefined::is($this->data->show_address)) {
            $this->receipt->setShowAddress($this->data->show_address);
        }

        if (!Undefined::is($this->data->show_phone)) {
            $this->receipt->setShowPhone($this->data->show_phone);
        }

        if (!Undefined::is($this->data->show_email)) {
            $this->receipt->setShowEmail($this->data->show_email);
        }

        if (!Undefined::is($this->data->show_fax)) {
            $this->receipt->setShowFax($this->data->show_fax);
        }

        if (!Undefined::is($this->data->show_website)) {
            $this->receipt->setShowWebsite($this->data->show_website);
        }

        if (!Undefined::is($this->data->show_facebook)) {
            $this->receipt->setShowFacebook($this->data->show_facebook);
        }

        if (!Undefined::is($this->data->show_twitter)) {
            $this->receipt->setShowTwitter($this->data->show_twitter);
        }

        if (!Undefined::is($this->data->show_instagram)) {
            $this->receipt->setShowInstagram($this->data->show_instagram);
        }

        if (!Undefined::is($this->data->show_youtube)) {
            $this->receipt->setShowYoutube($this->data->show_youtube);
        }

        if (!Undefined::is($this->data->show_order_date)) {
            $this->receipt->setShowOrderDate($this->data->show_order_date);
        }

        if (!Undefined::is($this->data->order_date_label)) {
            $this->receipt->setOrderDateLabel($this->data->order_date_label);
        }

        if (!Undefined::is($this->data->show_order_number)) {
            $this->receipt->setShowOrderNumber($this->data->show_order_number);
        }

        if (!Undefined::is($this->data->order_number_label)) {
            $this->receipt->setOrderNumberLabel($this->data->order_number_label);
        }

        if (!Undefined::is($this->data->show_order_customer)) {
            $this->receipt->setShowOrderCustomer($this->data->show_order_customer);
        }

        if (!Undefined::is($this->data->order_customer_label)) {
            $this->receipt->setOrderCustomerLabel($this->data->order_customer_label);
        }

        if (!Undefined::is($this->data->show_shipping)) {
            $this->receipt->setShowShipping($this->data->show_shipping);
        }

        if (!Undefined::is($this->data->shipping_label)) {
            $this->receipt->setShippingLabel($this->data->shipping_label);
        }

        if (!Undefined::is($this->data->show_order_register)) {
            $this->receipt->setShowOrderRegister($this->data->show_order_register);
        }

        if (!Undefined::is($this->data->order_register_label)) {
            $this->receipt->setOrderRegisterLabel($this->data->order_register_label);
        }

        if (!Undefined::is($this->data->show_cashier)) {
            $this->receipt->setShowCashier($this->data->show_cashier);
        }

        if (!Undefined::is($this->data->cashier_label)) {
            $this->receipt->setCashierLabel($this->data->cashier_label);
        }

        if (!Undefined::is($this->data->show_customer_note)) {
            $this->receipt->setShowCustomerNote($this->data->show_customer_note);
        }

        if (!Undefined::is($this->data->customer_note_label)) {
            $this->receipt->setCustomerNoteLabel($this->data->customer_note_label);
        }

        $this->receipt->save();

        return $this->receipt;
    }

    public static function make(
        Receipt $receipt,
        UpdateReceiptData $data
    ) {
        return new static(
            $receipt,
            $data,
        );
    }
}
