<?php

namespace Posify\Core\UseCases;

use Posify\Core\DataTransferObjects\UpdateRegisterData;
use Posify\Core\Entities\Register;
use Posify\Core\ValueObjects\Undefined;

class UpdateRegister
{
    public Register $register;
    public UpdateRegisterData $data;

    public function __construct(
        Register $register,
        UpdateRegisterData $data
    ) {
        $this->register = $register;
        $this->data = $data;
    }

    public function handle(): Register
    {
        if (!Undefined::is($this->data->name)) {
            $this->register->setName($this->data->name);
        }

        if (!Undefined::is($this->data->enabled)) {
            $this->register->setEnabled($this->data->enabled);
        }

        if (!Undefined::is($this->data->closing_report_note_enabled)) {
            $this->register->setClosingReportNoteEnabled($this->data->closing_report_note_enabled);
        }

        if (!Undefined::is($this->data->shipping_methods)) {
            $this->register->setShippingMethods($this->data->shipping_methods);
        }

        if (!Undefined::is($this->data->tax_classes)) {
            $this->register->setTaxClasses($this->data->tax_classes);
        }

        if (!Undefined::is($this->data->tax_status)) {
            $this->register->setTaxStatus($this->data->tax_status);
        }

        if (!Undefined::is($this->data->scan_enabled)) {
            $this->register->setScanEnabled($this->data->scan_enabled);
        }

        if (!Undefined::is($this->data->guest_checkout_enabled)) {
            $this->register->setGuestCheckoutEnabled($this->data->guest_checkout_enabled);
        }

        if (!Undefined::is($this->data->create_product_enabled)) {
            $this->register->setCreateProductEnabled($this->data->create_product_enabled);
        }

        if (!Undefined::is($this->data->shipping_enabled)) {
            $this->register->setShippingEnabled($this->data->shipping_enabled);
        }

        if (!Undefined::is($this->data->closing_report_enabled)) {
            $this->register->setClosingReportEnabled($this->data->closing_report_enabled);
        }

        if (!Undefined::is($this->data->closing_report_note_enabled)) {
            $this->register->setClosingReportNoteEnabled($this->data->closing_report_note_enabled);
        }

        if (!Undefined::is($this->data->catalog_include_type)) {
            $this->register->setCatalogIncludeType($this->data->catalog_include_type);
        }

        if (!Undefined::is($this->data->catalog_include_categories)) {
            $this->register->setCatalogIncludeCategories($this->data->catalog_include_categories);
        }

        if (!Undefined::is($this->data->catalog_include_products)) {
            $this->register->setCatalogIncludeProducts($this->data->catalog_include_products);
        }

        if (!Undefined::is($this->data->catalog_show_in_pos_type)) {
            $this->register->setCatalogShowInPosType($this->data->catalog_show_in_pos_type);
        }

        if (!Undefined::is($this->data->numeric_controller_discount_presets)) {
            $this->register->setNumericControllerDiscountPresets($this->data->numeric_controller_discount_presets);
        }

        if (!Undefined::is($this->data->fee_and_discount_presets)) {
            $this->register->setFeeAndDiscountPresets($this->data->fee_and_discount_presets);
        }

        if (!Undefined::is($this->data->audio_enabled)) {
            $this->register->setAudioEnabled($this->data->audio_enabled);
        }

        if (!Undefined::is($this->data->auto_print_receipt_enabled)) {
            $this->register->setAutoPrintReceiptEnabled($this->data->auto_print_receipt_enabled);
        }

        if (!Undefined::is($this->data->payment_gateways)) {
            $this->register->setPaymentGateways($this->data->payment_gateways);
        }

        if (!Undefined::is($this->data->default_payment_gateway)) {
            $this->register->setDefaultPaymentGateway($this->data->default_payment_gateway);
        }

        if (!Undefined::is($this->data->default_shipping_method)) {
            $this->register->setDefaultShippingMethod($this->data->default_shipping_method);
        }

        if (!Undefined::is($this->data->default_tax_class)) {
            $this->register->setDefaultTaxClass($this->data->default_tax_class);
        }

        if (!Undefined::is($this->data->default_tax_status)) {
            $this->register->setDefaultTaxStatus($this->data->default_tax_status);
        }

        if (!Undefined::is($this->data->receipt_id)) {
            $this->register->setReceiptId($this->data->receipt_id);
        }

        if (!Undefined::is($this->data->show_stock_quantity)) {
            $this->register->setShowStockQuantity($this->data->show_stock_quantity);
        }

        $this->register->save();

        return $this->register;
    }

    public static function make(
        Register $register,
        UpdateRegisterData $data
    ) {
        return new static(
            $register,
            $data,
        );
    }
}
