<?php

namespace Posify\Core\Utilities;

use Posify\Core\ValueObjects\Undefined;

class Sanitized
{
    public static $emptyStringIsNull = true;

    public static function string($value)
    {
        if (Undefined::is($value)) {
            return $value;
        }

        $value = static::toNullIfEmptyString($value);

        return $value;
    }

    public static function int($value)
    {
        if (Undefined::is($value)) {
            return $value;
        }

        $value = static::toNullIfEmptyString($value);

        return (int) $value;
    }

    public static function array($value)
    {
        if (Undefined::is($value)) {
            return $value;
        }

        $value = static::toNullIfEmptyString($value);

        return (array) $value;
    }

    public static function toNullIfEmptyString($value)
    {
        if (Undefined::is($value)) {
            return $value;
        }

        if (is_string($value) === false) {
            return $value;
        }

        if (self::$emptyStringIsNull && $value === '') {
            return null;
        }

        return $value;
    }

    public static function bool($value)
    {
        if (Undefined::is($value)) {
            return $value;
        }

        $value = static::toNullIfEmptyString($value);

        return (bool) $value;
    }
}
