<?php

namespace Posify\CustomerLicense;

use Posify\CustomerLicense\LicenseInfo;

class LicenseManager
{
    protected static $instance = null;

    protected $licenseKey = null;

    protected $product;

    public function __construct()
    {
        //
    }

    public static function getInstance()
    {
        if (is_null(static::$instance)) {
            static::$instance = new static();
        }

        return static::$instance;
    }

    public function setLicenseKey($licenseKey)
    {
        $this->licenseKey = $licenseKey;
    }

    public function setProduct($product)
    {
        $this->product = $product;
    }

    public function getLicense(): ?LicenseInfo
    {
        if (!$this->licenseKey) {
            return null;
        }

        $licenseRawInfo = $this->getLicenseAsArray();

        if (!$licenseRawInfo) {
            return null;
        }

        return LicenseInfo::make($licenseRawInfo);
    }

    public function verify($licenseKey = null)
    {
        if (!$licenseKey) {
            $licenseKey = $this->licenseKey;
        }

        $domain = Utils::getCorrectDomain(home_url());

        if (!$domain) {
            return [false, 'Empty domain'];
        }

        $url = Utils::getLicenseServerUrl('license/verify');

        $response = wp_remote_post($url, [
            'body' => [
                'key' => $licenseKey,
                'domain' => $domain,
            ]
        ]);

        if (is_wp_error($response)) {
            return [false, 'Bad request'];
        }

        $json = json_decode($response['body'], true);

        $verifyStatus = $json['status'];

        if ($verifyStatus === 'valid') {
            return [true, 'Active successfully'];
        }

        return [false, $json['invalid_message']];
    }

    public function hasLicense()
    {
        return !!$this->licenseKey;
    }

    public function removeLicense()
    {
        $this->licenseKey = '';

        do_action('posify_remove_license_key', $this->product, $this->licenseKey);
    }

    public function saveLicenseKey()
    {
        do_action('posify_save_license_key', $this->product, $this->licenseKey);
    }

    protected function getLicenseAsArray()
    {
        return json_decode(base64_decode($this->licenseKey), true);
    }

    public function getLicenseAsString()
    {
        return $this->licenseKey;
    }

    public function getUpdateInfo()
    {
        $args = [
            'product' => $this->product,
            'key' => $this->licenseKey,
            'domain' => Utils::getCorrectDomain(home_url()),
        ];

        $query = build_query($args);

        $remote = wp_remote_get(
            Utils::getLicenseServerUrl('product-update-info?') . $query,
            [
                'timeout' => 10,
                'headers' => [
                    'Accept' => 'application/json'
                ]
            ]
        );

        return $remote;
    }
}
