<?php

use Posify\Woocommerce\Http\Api\Controllers\AuthController;
use Posify\Woocommerce\Http\Api\Controllers\CustomerLicenseController;
use Posify\Woocommerce\Http\Api\Controllers\EmployeeController;
use Posify\Woocommerce\Http\Api\Controllers\LanguageController;
use Posify\Woocommerce\Http\Api\Controllers\PingController;
use Posify\Woocommerce\Http\Api\Controllers\PosController;
use Posify\Woocommerce\Http\Api\Controllers\ReceiptController;
use Posify\Woocommerce\Http\Api\Controllers\RegisterCashController;
use Posify\Woocommerce\Http\Api\Controllers\RegisterController;
use Posify\Woocommerce\Http\Api\Controllers\RegisterSessionController;
use Posify\Woocommerce\Http\Api\Controllers\ReportController\CurrentRegisterSessionReportAction;
use Posify\Woocommerce\Http\Api\Controllers\ReportController\OverviewReportAction;
use Posify\Woocommerce\Http\Api\Controllers\SettingController;
use Posify\Woocommerce\Http\Api\Controllers\StoreController;
use Posify\Woocommerce\Http\Api\Controllers\StoreEmployeeController;

if (!defined('ABSPATH')) exit;

/**
 * Auth routes
 */
posify_route('POST', 'auth/login', posify_controller_action(AuthController::class, 'login'), '__return_true');
posify_route('GET', 'auth/me', posify_controller_action(AuthController::class, 'me'));
posify_route('DELETE', 'auth/logout', posify_controller_action(AuthController::class, 'logout'));

/**
 * Ping routes
 */
posify_route('GET', 'ping', posify_controller_action(PingController::class, '__invoke'), '__return_true');

/**
 * POS routes
 */
posify_route('GET', 'pos/(?P<session_id>\d+)', posify_controller_action(PosController::class, '__invoke'));

/**
 * Setting routes
 */
posify_route('PUT', 'settings', posify_controller_action(SettingController::class, 'update'));
posify_route('GET', 'settings', posify_controller_action(SettingController::class, 'show'), '__return_true');

/**
 * Language routes
 */
posify_route('GET', 'languages/(?P<lang>[\w-]+)/translations', posify_controller_action(LanguageController::class, 'translations'), '__return_true');

/**
 * Store routes
 */
posify_route('GET', 'stores', posify_controller_action(StoreController::class, 'index'));
posify_route('POST', 'stores', posify_controller_action(StoreController::class, 'create'));
posify_route('GET', 'stores/(?P<id>\d+)', posify_controller_action(StoreController::class, 'show'));
posify_route('PUT', 'stores/(?P<id>\d+)', posify_controller_action(StoreController::class, 'update'));
posify_route('DELETE', 'stores/(?P<id>\d+)', posify_controller_action(StoreController::class, 'delete'));
posify_route('POST', 'stores/batch', posify_controller_action(StoreController::class, 'batch'));

/**
 * Store employee routes
 */
posify_route('GET', 'stores/(?P<store_id>\d+)/employees', posify_controller_action(StoreEmployeeController::class, 'index'));
posify_route('POST', 'stores/(?P<store_id>\d+)/employees', posify_controller_action(StoreEmployeeController::class, 'create'));
posify_route('PUT', 'stores/(?P<store_id>\d+)/employees/(?P<id>\d+)', posify_controller_action(StoreEmployeeController::class, 'update'));
posify_route('DELETE', 'stores/(?P<store_id>\d+)/employees/(?P<id>\d+)', posify_controller_action(StoreEmployeeController::class, 'delete'));
posify_route('POST', 'stores/(?P<store_id>\d+)/employees/batch', posify_controller_action(StoreEmployeeController::class, 'batch'));

/**
 * Register routes
 */
posify_route('GET', 'registers', posify_controller_action(RegisterController::class, 'index'));
posify_route('POST', 'registers', posify_controller_action(RegisterController::class, 'create'));
posify_route('GET', 'registers/(?P<id>\d+)', posify_controller_action(RegisterController::class, 'show'));
posify_route('PUT', 'registers/(?P<id>\d+)', posify_controller_action(RegisterController::class, 'update'));
posify_route('DELETE', 'registers/(?P<id>\d+)', posify_controller_action(RegisterController::class, 'delete'));
posify_route('POST', 'registers/batch', posify_controller_action(RegisterController::class, 'batch'));

/**
 * Employee routes
 */
posify_route('GET', 'employees', posify_controller_action(EmployeeController::class, 'index'));

/**
 * Register session routes
 */
posify_route('GET', 'register-sessions', posify_controller_action(RegisterSessionController::class, 'index'));
posify_route('GET', 'register-sessions/(?P<id>\d+)', posify_controller_action(RegisterSessionController::class, 'show'));
posify_route('GET', 'registers/(?P<register_id>\d+)/sessions/current', posify_controller_action(RegisterSessionController::class, 'showCurrent'));
posify_route('POST', 'registers/(?P<register_id>\d+)/sessions/current', posify_controller_action(RegisterSessionController::class, 'open'));
posify_route('PUT', 'registers/(?P<register_id>\d+)/sessions/current/take-over', posify_controller_action(RegisterSessionController::class, 'takeOver'));
posify_route('DELETE', 'registers/(?P<register_id>\d+)/sessions/current', posify_controller_action(RegisterSessionController::class, 'closeCurrent'));
posify_route('PUT', 'register-sessions/(?P<id>\d+)/close', posify_controller_action(RegisterSessionController::class, 'close'));

/**
 * Register cash routes
 */
posify_route('GET', 'register-cashes', posify_controller_action(RegisterCashController::class, 'index'));
posify_route('GET', 'registers/(?P<register_id>\d+)/sessions/current/cashes', posify_controller_action(RegisterCashController::class, 'getListByCurrentRegisterSession'));
posify_route('POST', 'registers/(?P<register_id>\d+)/sessions/current/cashes', posify_controller_action(RegisterCashController::class, 'create'));

/**
 * Receipt routes
 */
posify_route('GET', 'receipts', posify_controller_action(ReceiptController::class, 'index'));
posify_route('POST', 'receipts', posify_controller_action(ReceiptController::class, 'create'));
posify_route('GET', 'receipts/(?P<id>\d+)', posify_controller_action(ReceiptController::class, 'show'));
posify_route('PUT', 'receipts/(?P<id>\d+)', posify_controller_action(ReceiptController::class, 'update'));
posify_route('DELETE', 'receipts/(?P<id>\d+)', posify_controller_action(ReceiptController::class, 'delete'));
posify_route('POST', 'receipts/batch', posify_controller_action(ReceiptController::class, 'batch'));

/**
 * Report routes
 */
posify_route('GET', 'reports/overview', posify_controller_action(OverviewReportAction::class, '__invoke'));
posify_route('GET', 'reports/registers/(?P<register_id>\d+)/sessions/current', posify_controller_action(CurrentRegisterSessionReportAction::class, '__invoke'));

/**
 * License routes
 */
posify_route('GET', 'license', posify_controller_action(CustomerLicenseController::class, 'status'));
posify_route('POST', 'license', posify_controller_action(CustomerLicenseController::class, 'active'));
posify_route('DELETE', 'license', posify_controller_action(CustomerLicenseController::class, 'remove'));
